@@ -26,34 +26,45 @@ import java.net.URLDecoder;
 import java.nio.charset.StandardCharsets;
 
 /**
- * file loader
- *
+ * File loader to load files from file system
  */
 public class FileLoader {
 
     private static final Logger LOGGER = LoggerFactory.getLogger(FileLoader.class);
 
+    /**
+     * Load file by name.
+     *
+     * @param name the file name
+     * @return the file if found, or null if not found
+     * @throws IllegalArgumentException if name is null
+     */
     public static File load(String name) {
+        if (name == null) {
+            throw new IllegalArgumentException("name can't be null");
+        }
+
         try {
-            if (name == null) {
-                throw new IllegalArgumentException("name can't be null");
-            }
             String decodedPath = URLDecoder.decode(name, StandardCharsets.UTF_8.name());
-
             return getFileFromFileSystem(decodedPath);
-
         } catch (UnsupportedEncodingException e) {
-            LOGGER.error("decode name error: {}", e.getMessage(), e);
+            LOGGER.error("Failed to decode file name: {}", name, e);
         }
 
         return null;
     }
 
+    /**
+     * Get file from file system with multiple path attempts.
+     *
+     * @param decodedPath the decoded file path
+     * @return the file if found, or null if not found
+     */
     private static File getFileFromFileSystem(String decodedPath) {
-
         // run with jar file and not package third lib into jar file, this.getClass().getClassLoader() will be null
         URL resourceUrl = FileLoader.class.getClassLoader().getResource("");
         String[] tryPaths;
+
         if (resourceUrl != null) {
             tryPaths = new String[] {
                 // first: project dir
