@@ -20,6 +20,7 @@ import org.apache.seata.common.exception.NotSupportYetException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.lang.reflect.Constructor;
 import java.lang.reflect.Field;
 import java.lang.reflect.Modifier;
 import java.util.Date;
@@ -34,6 +35,12 @@ public class BeanUtils {
 
     protected static final Logger LOGGER = LoggerFactory.getLogger(BeanUtils.class);
 
+    /**
+     * Convert bean to string representation
+     *
+     * @param o the object to convert
+     * @return string representation of the object
+     */
     public static String beanToString(Object o) {
         if (o == null) {
             return null;
@@ -72,7 +79,9 @@ public class BeanUtils {
             return null;
         }
         try {
-            Object instance = clazz.newInstance();
+            // Use getDeclaredConstructor instead of newInstance which is deprecated since Java 9
+            Constructor<?> constructor = clazz.getDeclaredConstructor();
+            Object instance = constructor.newInstance();
             Field[] fields = instance.getClass().getDeclaredFields();
             for (Field field : fields) {
                 int modifiers = field.getModifiers();
@@ -110,6 +119,8 @@ public class BeanUtils {
             throw new NotSupportYetException("map to " + clazz.toString() + " failed:" + e.getMessage(), e);
         } catch (InstantiationException e) {
             throw new NotSupportYetException("map to " + clazz.toString() + " failed:" + e.getMessage(), e);
+        } catch (Exception e) {
+            throw new NotSupportYetException("map to " + clazz.toString() + " failed:" + e.getMessage(), e);
         }
     }
 
