@@ -282,29 +282,50 @@ public class StringUtilsTest {
         Assertions.assertFalse(CycleDependencyHandler.isStarting());
 
         // case: Object
-        Assertions.assertEquals("CycleDependency(s=\"a\", obj=null)", StringUtils.toString(CycleDependency.A));
+        String resultCycleDependencyA = StringUtils.toString(CycleDependency.A);
+        Assertions.assertTrue(resultCycleDependencyA.startsWith("CycleDependency("));
+        Assertions.assertTrue(resultCycleDependencyA.endsWith(")"));
+        Assertions.assertTrue(resultCycleDependencyA.contains("s=\"a\""));
+        Assertions.assertTrue(resultCycleDependencyA.contains("obj=null"));
         // case: Object, and cycle dependency
         CycleDependency obj = new CycleDependency("c");
         obj.setObj(obj);
-        Assertions.assertEquals("CycleDependency(s=\"c\", obj=(this CycleDependency))", StringUtils.toString(obj));
+        String resultCycleDependencyObj = StringUtils.toString(obj);
+        Assertions.assertTrue(resultCycleDependencyObj.startsWith("CycleDependency("));
+        Assertions.assertTrue(resultCycleDependencyObj.endsWith(")"));
+        Assertions.assertTrue(resultCycleDependencyObj.contains("s=\"c\""));
+        Assertions.assertTrue(resultCycleDependencyObj.contains("obj=(this CycleDependency)"));
         // case: Object
         CycleDependency obj2 = new CycleDependency("d");
         obj.setObj(obj2);
-        Assertions.assertEquals(
-                "CycleDependency(s=\"c\", obj=CycleDependency(s=\"d\", obj=null))", StringUtils.toString(obj));
+        String actualCD = StringUtils.toString(obj);
+        String expectedCanonicalCD = "CycleDependency(s=\"c\", obj=CycleDependency(s=\"d\", obj=null))";
+        String expectedAlternateCD = "CycleDependency(obj=CycleDependency(obj=null, s=\"d\"), s=\"c\")";
+        Assertions.assertTrue(
+                expectedCanonicalCD.equals(actualCD) || expectedAlternateCD.equals(actualCD),
+                "Unexpected String representation for nested CycleDependency. Actual: " + actualCD);
         // case: Object, and cycle dependency
         TestClass a = new TestClass();
         a.setObj(a);
-        Assertions.assertEquals("TestClass(obj=(this TestClass), s=null)", StringUtils.toString(a));
+        String resultA = StringUtils.toString(a); // check for the presence of field-value pairs regardless of order
+        Assertions.assertTrue(resultA.startsWith("TestClass("));
+        Assertions.assertTrue(resultA.endsWith(")"));
+        Assertions.assertTrue(resultA.contains("obj=(this TestClass)"));
+        Assertions.assertTrue(resultA.contains("s=null"));
         // case: Object, and cycle dependency（deep case）
         TestClass b = new TestClass();
         TestClass c = new TestClass();
         b.setObj(c);
         c.setObj(a);
         a.setObj(b);
-        Assertions.assertEquals(
-                "TestClass(obj=TestClass(obj=TestClass(obj=(ref TestClass), s=null), s=null), s=null)",
-                StringUtils.toString(a));
+        String actual = StringUtils.toString(a);
+        String expectedCanonical =
+                "TestClass(obj=TestClass(obj=TestClass(obj=(ref TestClass), s=null), s=null), s=null)";
+        String expectedAlternate =
+                "TestClass(s=null, obj=TestClass(s=null, obj=TestClass(s=null, obj=(ref TestClass))))";
+        Assertions.assertTrue(
+                expectedCanonical.equals(actual) || expectedAlternate.equals(actual),
+                "Unexpected String representation for deep cycle dependency. Actual: " + actual);
 
         // case: anonymous class from an interface
         Object anonymousObj = new TestInterface() {
@@ -491,4 +512,21 @@ public class StringUtilsTest {
         Assertions.assertFalse(StringUtils.hasText("   "));
         Assertions.assertTrue(StringUtils.hasText(whitespaceCharSequence));
     }
+
+    @Test
+    public void testHasLength() {
+        Assertions.assertFalse(StringUtils.hasLength(null));
+        Assertions.assertFalse(StringUtils.hasLength(""));
+        Assertions.assertTrue(StringUtils.hasLength(" "));
+        Assertions.assertTrue(StringUtils.hasLength("foo"));
+    }
+
+    @Test
+    public void testHasText() {
+        Assertions.assertFalse(StringUtils.hasText(null));
+        Assertions.assertFalse(StringUtils.hasText(""));
+        Assertions.assertFalse(StringUtils.hasText(" "));
+        Assertions.assertTrue(StringUtils.hasText("foo"));
+        Assertions.assertTrue(StringUtils.hasText(" foo "));
+    }
 }
