@@ -20,5 +20,4 @@ package io.seata.core.constants;
  * Compatible for dubbo dubbo-filter-seata
  */
 @Deprecated
-public class DubboConstants extends org.apache.seata.core.constants.DubboConstants {
-}
+public class DubboConstants extends org.apache.seata.core.constants.DubboConstants {}
