@@ -16,11 +16,9 @@
  */
 package io.seata.discovery.loadbalance;
 
-
 /**
  * The interface Load balance.
  * Notes: used for io.seata SPI interface
  */
 @Deprecated
-public interface LoadBalance extends org.apache.seata.discovery.loadbalance.LoadBalance {
-}
+public interface LoadBalance extends org.apache.seata.discovery.loadbalance.LoadBalance {}
