@@ -20,5 +20,4 @@ package io.seata.tm.api;
  * The interface Failure handler.
  */
 @Deprecated
-public interface FailureHandler extends org.apache.seata.tm.api.FailureHandler<GlobalTransaction> {
-}
+public interface FailureHandler extends org.apache.seata.tm.api.FailureHandler<GlobalTransaction> {}
