@@ -66,6 +66,7 @@ public class DataSourceProxyXATest {
 
         DruidDataSource druidDataSource = new DruidDataSource();
         druidDataSource.setDriver(driver);
+        druidDataSource.setUrl("jdbc:mysql:xxx");
         DataSourceProxyXA dataSourceProxyXA = new DataSourceProxyXA(druidDataSource);
         RootContext.unbind();
         Connection connFromDataSourceProxyXA = dataSourceProxyXA.getConnection();
@@ -78,7 +79,7 @@ public class DataSourceProxyXATest {
         Connection wrappedConnection = connectionProxyXA.getWrappedConnection();
         Assertions.assertTrue(wrappedConnection instanceof PooledConnection);
 
-        Connection wrappedPhysicalConn = ((PooledConnection) wrappedConnection).getConnection();
+        Connection wrappedPhysicalConn = wrappedConnection.unwrap(Connection.class);
         Assertions.assertSame(wrappedPhysicalConn, connection);
 
         XAConnection xaConnection = connectionProxyXA.getWrappedXAConnection();
@@ -101,6 +102,7 @@ public class DataSourceProxyXATest {
 
         DruidDataSource druidDataSource = new DruidDataSource();
         druidDataSource.setDriver(driver);
+        druidDataSource.setUrl("jdbc:mariadb:xxx");
         DataSourceProxyXA dataSourceProxyXA = new DataSourceProxyXA(druidDataSource);
         RootContext.unbind();
         Connection connFromDataSourceProxyXA = dataSourceProxyXA.getConnection();
@@ -114,7 +116,7 @@ public class DataSourceProxyXATest {
         Connection wrappedConnection = connectionProxyXA.getWrappedConnection();
         Assertions.assertTrue(wrappedConnection instanceof PooledConnection);
 
-        Connection wrappedPhysicalConn = ((PooledConnection) wrappedConnection).getConnection();
+        Connection wrappedPhysicalConn = wrappedConnection.unwrap(Connection.class);
         Assertions.assertSame(wrappedPhysicalConn, connection);
 
         XAConnection xaConnection = connectionProxyXA.getWrappedXAConnection();
