@@ -18,12 +18,11 @@ import React from 'react';
 import { ConfigProvider, Table, Button, DatePicker, Form, Icon, Switch, Pagination, Dialog, Input, Select, Message } from '@alicloud/console-components';
 import Actions, { LinkButton } from '@alicloud/console-components-actions';
 import { withRouter } from 'react-router-dom';
+import { connect } from 'react-redux';
 import Page from '@/components/Page';
 import { GlobalProps } from '@/module';
-import styled, { css } from 'styled-components';
 import getData, { changeGlobalData, deleteBranchData, deleteGlobalData, GlobalSessionParam, sendGlobalCommitOrRollback,
-  startBranchData, startGlobalData, stopBranchData, stopGlobalData, forceDeleteGlobalData, forceDeleteBranchData, fetchNamespace } from '@/service/transactionInfo';
-import PropTypes from 'prop-types';
+  startBranchData, startGlobalData, stopBranchData, stopGlobalData, forceDeleteGlobalData, forceDeleteBranchData, fetchNamespaceV2, addGroup, changeGroup } from '@/service/transactionInfo';
 import moment from 'moment';
 
 import './index.scss';
@@ -48,11 +47,30 @@ type TransactionInfoState = {
   xid : string;
   currentBranchSession: Array<any>;
   globalSessionParam : GlobalSessionParam;
-  namespaceOptions: Map<string, { clusters: string[], vgroups: string[] }>;
+  namespaceOptions: Map<string, NamespaceData>;
   clusters: Array<string>;
   vgroups: Array<string>;
+  createVGroupDialogVisible: boolean;
+  vGroupName: string;
+  changeVGroupDialogVisible: boolean;
+  selectedVGroup: string;
+  targetNamespace: string;
+  targetClusters: Array<string>;
+  targetCluster: string;
+  targetUnits: Array<string>;
+  targetUnit: string;
+  originalNamespace: string;
+  originalClusters: Array<string>;
+  originalCluster: string;
+  originalVGroups: Array<string>;
+  createNamespace: string;
+  createCluster: string;
+  createUnits: Array<string>;
+  createUnit: string;
 }
 
+type NamespaceData = { clusters: string[], clusterVgroups: {[key: string]: string[]}, clusterUnits: {[key: string]: string[]}, clusterTypes: {[key: string]: string} };
+
 const statusList:Array<StatusType> = [
   {
     label: 'AsyncCommitting',
@@ -293,14 +311,11 @@ const warnning = new Map([
     ['SAGA', 'The force delete will only delete session in server.']])],
 ])
 
+const VGROUP_REFRESH_DELAY_MS = 6000;
+
 class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState> {
   static displayName = 'TransactionInfo';
 
-  static propTypes = {
-    locale: PropTypes.object,
-    history: PropTypes.object,
-  };
-
   state: TransactionInfoState = {
     list: [],
     total: 0,
@@ -313,9 +328,26 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
       pageSize: 10,
       pageNum: 1,
     },
-    namespaceOptions: new Map<string, { clusters: string[], vgroups: string[] }>(),
+    namespaceOptions: new Map<string, NamespaceData>(),
     clusters: [],
     vgroups: [],
+    createVGroupDialogVisible: false,
+    vGroupName: '',
+    changeVGroupDialogVisible: false,
+    selectedVGroup: '',
+    targetNamespace: '',
+    targetClusters: [],
+    targetCluster: '',
+    targetUnits: [],
+    targetUnit: '',
+    originalNamespace: '',
+    originalClusters: [],
+    originalCluster: '',
+    originalVGroups: [],
+    createNamespace: '',
+    createCluster: '',
+    createUnits: [],
+    createUnit: '',
   };
   componentDidMount = () => {
     // search once by default
@@ -323,62 +355,82 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
   }
   loadNamespaces = async () => {
     try {
-      const namespaces = await fetchNamespace();
-      const namespaceOptions = new Map<string, { clusters: string[], vgroups: string[] }>();
+      const namespaces = await fetchNamespaceV2();
+      const namespaceOptions = new Map<string, NamespaceData>();
+
       Object.keys(namespaces).forEach(namespaceKey => {
         const namespaceData = namespaces[namespaceKey];
+        const clustersData = namespaceData.clusters || {};
+        const clusterVgroups: {[key: string]: string[]} = {};
+        const clusterUnits: {[key: string]: string[]} = {};
+        const clusterTypes: {[key: string]: string} = {};
+        Object.keys(clustersData).forEach(clusterName => {
+          const cluster = clustersData[clusterName];
+          clusterVgroups[clusterName] = cluster.vgroups || [];
+          clusterUnits[clusterName] = cluster.units || [];
+          clusterTypes[clusterName] = cluster.type || 'default';
+        });
+        const clusters = Object.keys(clustersData);
         namespaceOptions.set(namespaceKey, {
-          clusters: namespaceData.clusters,
-          vgroups: namespaceData.vgroups,
+          clusters,
+          clusterVgroups,
+          clusterUnits,
+          clusterTypes,
         });
       });
         if (namespaceOptions.size > 0) {
             // Set default namespace to the first option
             const firstNamespace = Array.from(namespaceOptions.keys())[0];
             const selectedNamespace = namespaceOptions.get(firstNamespace);
-            this.setState({
+            const firstCluster = selectedNamespace ? selectedNamespace.clusters[0] : undefined;
+            const clusterVgroups = selectedNamespace ? selectedNamespace.clusterVgroups : {};
+            const selectedVgroups = firstCluster ? clusterVgroups[firstCluster] || [] : [];
+            this.setState(prevState => ({
                 namespaceOptions,
                 globalSessionParam: {
-                    ...this.state.globalSessionParam,
+                    ...prevState.globalSessionParam,
                     namespace: firstNamespace,
-                    cluster: selectedNamespace ? selectedNamespace.clusters[0] : undefined,
+                    cluster: firstCluster,
                 },
                 clusters: selectedNamespace ? selectedNamespace.clusters : [],
-                vgroups: selectedNamespace ? selectedNamespace.vgroups : [],
-            });
-            this.search();
-        } else {
-            this.setState({
-                namespaceOptions,
-            });
-        }
+                vgroups: selectedVgroups,
+            }));
+             this.search();
+         } else {
+             this.setState({
+                 namespaceOptions,
+             });
+         }
     } catch (error) {
       console.error('Failed to fetch namespaces:', error);
     }
   }
   resetSearchFilter = () => {
-    this.setState({
+    this.setState(prevState => ({
       globalSessionParam: {
         withBranch: false,
         // pagination info don`t reset
-        pageSize: this.state.globalSessionParam.pageSize,
-        pageNum: this.state.globalSessionParam.pageNum,
+        pageSize: prevState.globalSessionParam.pageSize,
+        pageNum: prevState.globalSessionParam.pageNum,
       },
-    });
+      clusters: [],
+      vgroups: [],
+    }));
   }
 
   search = () => {
     this.setState({ loading: true });
+    const currentBranchSessionDialogVisible = this.state.branchSessionDialogVisible;
+    const currentXid = this.state.xid;
     getData(this.state.globalSessionParam).then(data => {
       // if the result set is empty, set the page number to go back to the first page
       if (data.total === 0) {
-        this.setState({
+        this.setState(prevState => ({
           list: [],
           total: 0,
           loading: false,
-          globalSessionParam: Object.assign(this.state.globalSessionParam,
-            { pageNum: 1 }),
-        });
+          globalSessionParam: { ...prevState.globalSessionParam, pageNum: 1 },
+        }));
         return;
       }
       // format time
@@ -396,19 +448,22 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
         }
       });
 
-      if (this.state.branchSessionDialogVisible) {
-        data.data.forEach((item: any) => {
-          if (item.xid == this.state.xid) {
-            this.state.currentBranchSession = item.branchSessionVOs
-          }
-        })
+      if (currentBranchSessionDialogVisible) {
+        const currentBranchSession = data.data.find((item: any) => item.xid == currentXid)?.branchSessionVOs || [];
+        this.setState({
+          list: data.data,
+          total: data.total,
+          loading: false,
+          currentBranchSession,
+        });
+      } else {
+        this.setState({
+          list: data.data,
+          total: data.total,
+          loading: false,
+        });
       }
-      this.setState({
-        list: data.data,
-        total: data.total,
-        loading: false,
-      });
-    }).catch(err => {
+    }).catch(() => {
       this.setState({ loading: false });
     });
   }
@@ -416,23 +471,41 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
   searchFilterOnChange = (key: string, val: string) => {
     if (key === 'namespace') {
       const selectedNamespace = this.state.namespaceOptions.get(val);
-      this.setState({
-        clusters: selectedNamespace ? selectedNamespace.clusters : [],
-        vgroups: selectedNamespace ? selectedNamespace.vgroups : [],
-        globalSessionParam: Object.assign(this.state.globalSessionParam, {[key]: val}),
-      });
+      const clusters = selectedNamespace ? selectedNamespace.clusters : [];
+      const firstCluster = clusters.length > 0 ? clusters[0] : undefined;
+      const clusterVgroups = selectedNamespace ? selectedNamespace.clusterVgroups : {};
+      const vgroups = firstCluster ? clusterVgroups[firstCluster] || [] : [];
+      this.setState(prevState => ({
+        clusters,
+        vgroups,
+        globalSessionParam: { ...prevState.globalSessionParam, [key]: val, cluster: firstCluster, vgroup: '' },
+      }));
+    } else if (key === 'cluster') {
+      const currentNamespace = this.state.globalSessionParam.namespace;
+      if (currentNamespace) {
+        const namespaceData = this.state.namespaceOptions.get(currentNamespace);
+        const clusterVgroups = namespaceData ? namespaceData.clusterVgroups : {};
+        const selectedVgroups = clusterVgroups[val] || [];
+        this.setState(prevState => ({
+          vgroups: selectedVgroups,
+          globalSessionParam: { ...prevState.globalSessionParam, [key]: val, vgroup: '' },
+        }));
+      } else {
+        this.setState(prevState => ({
+          globalSessionParam: { ...prevState.globalSessionParam, [key]: val, vgroup: '' },
+        }));
+      }
     } else {
-      this.setState({
-        globalSessionParam: Object.assign(this.state.globalSessionParam, {[key]: val}),
-      });
+      this.setState(prevState => ({
+        globalSessionParam: { ...prevState.globalSessionParam, [key]: val },
+      }));
     }
   };
 
-  branchSessionSwitchOnChange = (checked: boolean, e: any) => {
-    this.setState({
-      globalSessionParam: Object.assign(this.state.globalSessionParam,
-        { withBranch: checked }),
-    });
+  branchSessionSwitchOnChange = (checked: boolean, _e?: any) => {
+    this.setState(prevState => ({
+      globalSessionParam: { ...prevState.globalSessionParam, withBranch: checked },
+    }));
     if (checked) {
       // if checked, do search for load branch sessions
       this.search();
@@ -441,15 +514,14 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
 
   createTimeOnChange = (value: Array<any>) => {
     // timestamp(milliseconds)
-    const timeStart = value[0] == null ? null : moment(value[0]).unix() * 1000;
-    const timeEnd = value[1] == null ? null : moment(value[1]).unix() * 1000;
-    this.setState({
-      globalSessionParam: Object.assign(this.state.globalSessionParam,
-        { timeStart, timeEnd }),
-    });
+    const timeStart = value[0] == null ? undefined : moment(value[0]).unix() * 1000;
+    const timeEnd = value[1] == null ? undefined : moment(value[1]).unix() * 1000;
+    this.setState(prevState => ({
+      globalSessionParam: { ...prevState.globalSessionParam, timeStart, timeEnd },
+    }));
   }
 
-  statusCell = (val: number, index: number, record: any) => {
+  statusCell = (val: number, _index?: number, _record?: any) => {
     let icon;
     statusList.forEach((status: StatusType) => {
       if (status.value === val) {
@@ -465,7 +537,7 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
     return icon;
   }
 
-  branchSessionStatusCell = (val: number, index: number, record: any) => {
+  branchSessionStatusCell = (val: number, _index?: number, _record?: any) => {
     let icon;
     branchSessionStatusList.forEach((status: StatusType) => {
       if (status.value === val) {
@@ -482,7 +554,7 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
   }
 
   operateCell = (val: string, index: number, record: any) => {
-    const { locale = {}, history } = this.props;
+    const { locale, history } = this.props;
     const {
       showBranchSessionTitle,
       showGlobalLockTitle,
@@ -492,7 +564,7 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
       startGlobalSessionTitle,
       sendGlobalSessionTitle,
       changeGlobalSessionTitle,
-    } = locale;
+    } = locale?.TransactionInfo || {};
     let width = getCurrentLanguage() === enUsKey ? '450px' : '420px'
     let height = '120px';
     return (
@@ -525,6 +597,7 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
           {showGlobalLockTitle}
         </LinkButton>
 
+
         <Button
           onClick={() => {
             Dialog.confirm({
@@ -545,7 +618,7 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
                   title: 'Warnning',
                   content: <div dangerouslySetInnerHTML={{__html: commonWarnning + '<br>' + warnMessage}}/>,
                   onOk: () => {
-                    deleteGlobalData(record).then((rsp) => {
+                    deleteGlobalData(record).then(() => {
                       Message.success("Delete successfully")
                       this.search()
                     }).catch((rsp) => {
@@ -580,7 +653,7 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
                   title: 'Warnning',
                   content: <div dangerouslySetInnerHTML={{__html: commonWarnning + '<br>' + warnMessage}}/>,
                   onOk: () => {
-                    forceDeleteGlobalData(record).then((rsp) => {
+                    forceDeleteGlobalData(record).then(() => {
                       Message.success("Delete successfully")
                       this.search()
                     }).catch((rsp) => {
@@ -602,7 +675,7 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
                 title: 'Confirm',
                 content: 'Are you sure you want to start restart global transactions',
                 onOk: () => {
-                  startGlobalData(record).then((rsp) => {
+                  startGlobalData(record).then(() => {
                     Message.success("Start successfully")
                     this.search()
                   }).catch((rsp) => {
@@ -619,7 +692,7 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
             title: 'Confirm',
             content: 'Are you sure you want to stop stop global transactions',
             onOk: () => {
-              stopGlobalData(record).then((rsp) => {
+              stopGlobalData(record).then(() => {
                 Message.success("Stop successfully")
                 this.search()
               }).catch((rsp) => {
@@ -639,7 +712,7 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
               title: 'Confirm',
               content: 'Are you sure you want to send commit or rollback to global transactions',
               onOk: () => {
-                sendGlobalCommitOrRollback(record).then((rsp) => {
+                sendGlobalCommitOrRollback(record).then(() => {
                   Message.success("Send successfully")
                   this.search()
                 }).catch((rsp) => {
@@ -658,7 +731,7 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
               title: 'Confirm',
               content: 'Are you sure you want to change the global transactions status',
               onOk: () => {
-                changeGlobalData(record).then((rsp) => {
+                changeGlobalData(record).then(() => {
                   Message.success("Change successfully")
                   this.search()
                 }).catch((rsp) => {
@@ -675,14 +748,14 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
   }
 
   branchSessionDialogOperateCell = (val: string, index: number, record: any) => {
-    const { locale = {}, history } = this.props;
+    const { locale, history } = this.props;
     const {
       showGlobalLockTitle,
       deleteBranchSessionTitle,
       stopBranchSessionTitle,
       startBranchSessionTitle,
       forceDeleteBranchSessionTitle,
-    } = locale;
+    } = locale.TransactionInfo || {};
     let width = getCurrentLanguage() === enUsKey ? '500px' : '450px'
     let height = '120px';
     return (
@@ -718,7 +791,7 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
                   title: 'Warnning',
                   content: <div dangerouslySetInnerHTML={{__html: commonWarnning + '<br>' + warnMessage}}/>,
                   onOk: () => {
-                    deleteBranchData(record).then((rsp) => {
+                    deleteBranchData(record).then(() => {
                       Message.success("Delete successfully")
                       this.search()
                     }).catch((rsp) => {
@@ -744,7 +817,7 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
                   title: 'Warnning',
                   content: <div dangerouslySetInnerHTML={{__html: commonWarnning + '<br>' + warnMessage}}/>,
                   onOk: () => {
-                    forceDeleteBranchData(record).then((rsp) => {
+                    forceDeleteBranchData(record).then(() => {
                       Message.success("Delete successfully")
                       this.search()
                     }).catch((rsp) => {
@@ -766,7 +839,7 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
                 title: 'Confirm',
                 content: 'Are you sure you want to start branch transactions retry',
                 onOk: () => {
-                  startBranchData(record).then((rsp) => {
+                  startBranchData(record).then(() => {
                     Message.success("Start successfully")
                     this.search()
                   }).catch((rsp) => {
@@ -789,7 +862,7 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
                   title: 'Warnning',
                   content: <div dangerouslySetInnerHTML={{__html: commonWarnning + '<br>' + warnMessage}}/>,
                   onOk: () => {
-                    stopBranchData(record).then((rsp) => {
+                    stopBranchData(record).then(() => {
                       Message.success("Stop successfully")
                       this.search()
                     }).catch((rsp) => {
@@ -807,19 +880,17 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
       </Actions>);
   }
 
-  paginationOnChange = (current: number, e: {}) => {
-    this.setState({
-      globalSessionParam: Object.assign(this.state.globalSessionParam,
-        { pageNum: current }),
-    });
+  paginationOnChange = (current: number, _e?: any) => {
+    this.setState(prevState => ({
+      globalSessionParam: { ...prevState.globalSessionParam, pageNum: current },
+    }));
     this.search();
   }
 
   paginationOnPageSizeChange = (pageSize: number) => {
-    this.setState({
-      globalSessionParam: Object.assign(this.state.globalSessionParam,
-        { pageSize }),
-    });
+    this.setState(prevState => ({
+      globalSessionParam: { ...prevState.globalSessionParam, pageSize },
+    }));
     this.search();
   }
 
@@ -839,8 +910,127 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
     });
   }
 
+  showCreateVGroupDialog = () => {
+    this.setState(prevState => {
+      const clusterUnits = prevState.globalSessionParam.namespace ? prevState.namespaceOptions.get(prevState.globalSessionParam.namespace)?.clusterUnits || {} : {};
+      const units = prevState.globalSessionParam.cluster ? clusterUnits[prevState.globalSessionParam.cluster] || [] : [];
+      return {
+        createVGroupDialogVisible: true,
+        vGroupName: '',
+        createNamespace: prevState.globalSessionParam.namespace || '',
+        createCluster: prevState.globalSessionParam.cluster || '',
+        createUnits: units,
+        createUnit: units.length > 0 ? units[0] : '',
+      };
+    });
+  }
+
+  closeCreateVGroupDialog = () => {
+    this.setState({
+      createVGroupDialogVisible: false,
+      vGroupName: '',
+      createNamespace: '',
+      createCluster: '',
+      createUnits: [],
+      createUnit: '',
+    });
+  }
+
+  showChangeVGroupDialog = () => {
+    this.setState({
+      changeVGroupDialogVisible: true,
+      selectedVGroup: '',
+      targetNamespace: '',
+      targetClusters: [],
+      targetCluster: '',
+      targetUnits: [],
+      targetUnit: '',
+      originalNamespace: '',
+      originalClusters: [],
+      originalCluster: '',
+      originalVGroups: [],
+    });
+  }
+
+  closeChangeVGroupDialog = () => {
+    this.setState({
+      changeVGroupDialogVisible: false,
+      selectedVGroup: '',
+      targetNamespace: '',
+      targetClusters: [],
+      targetCluster: '',
+      targetUnits: [],
+      targetUnit: '',
+      originalNamespace: '',
+      originalClusters: [],
+      originalCluster: '',
+      originalVGroups: [],
+    });
+  }
+
+  handleCreateVGroup = () => {
+    const { locale } = this.props;
+    const { createVGroupErrorMessage, createVGroupSuccessMessage, createVGroupFailMessage } = locale.TransactionInfo || {};
+    const { createNamespace, createCluster, vGroupName, createUnit } = this.state;
+    if (!createNamespace || !createCluster || !vGroupName.trim()) {
+      Message.error(createVGroupErrorMessage);
+      return;
+    }
+
+    const clusterType = this.state.namespaceOptions.get(createNamespace)?.clusterTypes[createCluster];
+    const unitName = clusterType !== 'default' ? createUnit : '';
+
+    addGroup(createNamespace, createCluster, vGroupName.trim(), unitName).then(() => {
+      Message.success(createVGroupSuccessMessage);
+      this.closeCreateVGroupDialog();
+      // Delay 5 seconds before reloading namespaces to get the latest vgroup list
+      setTimeout(() => {
+        this.loadNamespaces();
+      }, VGROUP_REFRESH_DELAY_MS);
+    }).catch((error) => {
+      const backendMessage = lodashGet(error, 'data.message');
+      const displayMessage = backendMessage ? `${createVGroupFailMessage}: ${backendMessage}` : createVGroupFailMessage;
+      Message.error(displayMessage);
+    });
+  }
+
+    handleChangeVGroup = () => {
+    const { locale } = this.props;
+    const { changeVGroupSuccessMessage, changeVGroupFailMessage } = locale.TransactionInfo || {};
+    const { selectedVGroup, targetNamespace, targetCluster, targetUnit } = this.state;
+    if (!selectedVGroup || !targetNamespace || !targetCluster) {
+      return;
+    }
+
+    const targetClusterType = this.state.namespaceOptions.get(targetNamespace)?.clusterTypes[targetCluster];
+    const unitName = targetClusterType !== 'default' ? targetUnit : '';
+
+    changeGroup(targetNamespace, targetCluster, selectedVGroup, unitName).then(() => {
+      Message.success(changeVGroupSuccessMessage);
+      this.closeChangeVGroupDialog();
+      // Delay 5 seconds before reloading namespaces to get the latest vgroup list
+      setTimeout(() => {
+        this.loadNamespaces();
+      }, VGROUP_REFRESH_DELAY_MS);
+    }).catch((error) => {
+      const backendMessage = lodashGet(error, 'data.message');
+      const displayMessage = backendMessage ? `${changeVGroupFailMessage}: ${backendMessage}` : changeVGroupFailMessage;
+      Message.error(displayMessage);
+    });
+    }
+
+  isChangeVGroupDisabled = (): boolean => {
+    const { selectedVGroup, targetNamespace, targetCluster, targetUnit, namespaceOptions } = this.state;
+    if (!selectedVGroup || !targetNamespace || !targetCluster) {
+      return true;
+    }
+    const clusterType = namespaceOptions.get(targetNamespace)?.clusterTypes[targetCluster];
+    return clusterType !== 'default' && !targetUnit;
+  }
+
   render() {
-    const { locale = {} } = this.props;
+    const { locale } = this.props;
+    const transactionInfo = locale.TransactionInfo || {};
     const { title, subTitle, createTimeLabel,
       selectFilerPlaceholder,
       selectNamespaceFilerPlaceholder,
@@ -852,7 +1042,27 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
       searchButtonLabel,
       operateTitle,
       branchSessionDialogTitle,
-    } = locale;
+      createVGroupButtonLabel,
+      createVGroupDialogTitle,
+      createVGroupInputPlaceholder,
+      createVGroupConfirmButton,
+      changeVGroupButtonLabel,
+      changeVGroupDialogTitle,
+      namespaceLabel,
+      clusterLabel,
+      originalNamespaceLabel,
+      originalClusterLabel,
+      selectVGroupLabel,
+      targetNamespaceLabel,
+      targetClusterLabel,
+      vGroupNameLabel,
+      confirmButtonLabel,
+      selectOriginalNamespacePlaceholder,
+      selectOriginalClusterPlaceholder,
+      selectTargetNamespacePlaceholder,
+      selectTargetClusterPlaceholder,
+      selectVGroupPlaceholder,
+    } = transactionInfo;
     return (
       <Page
         title={title}
@@ -928,6 +1138,8 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
                   this.searchFilterOnChange('vgroup', value);
                 }}
                 dataSource={this.state.vgroups.map(value => ({ label: value, value }))}
+                value={this.state.globalSessionParam.vgroup}
+                key={this.state.globalSessionParam.cluster}
             />
           </FormItem>
           {/* {branch session switch} */}
@@ -949,6 +1161,18 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
               <Icon type="search" />{searchButtonLabel}
             </Form.Submit>
           </FormItem>
+          {/* {create vgroup button} */}
+          <FormItem>
+            <Button onClick={this.showCreateVGroupDialog}>
+              {createVGroupButtonLabel}
+            </Button>
+          </FormItem>
+          {/* {change vgroup button} */}
+          <FormItem>
+            <Button onClick={this.showChangeVGroupDialog}>
+              {changeVGroupButtonLabel}
+            </Button>
+          </FormItem>
         </Form>
         {/* global session table */}
         <div>
@@ -1004,9 +1228,199 @@ class TransactionInfo extends React.Component<GlobalProps, TransactionInfoState>
             />
           </Table>
         </Dialog>
+
+        {/* create vgroup dialog */}
+        <Dialog visible={this.state.createVGroupDialogVisible} title={createVGroupDialogTitle} footer={false} onClose={this.closeCreateVGroupDialog}>
+          <Form inline labelAlign="left">
+            <FormItem name="createNamespace" label={namespaceLabel}>
+              <Select
+                placeholder={selectNamespaceFilerPlaceholder}
+                onChange={(value: string) => {
+                  this.setState(prevState => {
+                    const clusters = value ? prevState.namespaceOptions.get(value)?.clusters || [] : [];
+                    const clusterUnits = prevState.namespaceOptions.get(value)?.clusterUnits || {};
+                    const units = clusters.length > 0 ? clusterUnits[clusters[0]] || [] : [];
+                    return {
+                      createNamespace: value,
+                      createCluster: clusters.length > 0 ? clusters[0] : '',
+                      createUnits: units,
+                      createUnit: units.length > 0 ? units[0] : '',
+                    };
+                  });
+                }}
+                dataSource={Array.from(this.state.namespaceOptions.keys()).map(key => ({ label: key, value: key }))}
+                value={this.state.createNamespace}
+              />
+            </FormItem>
+            <FormItem name="createCluster" label={clusterLabel}>
+              <Select
+                placeholder={selectClusterFilerPlaceholder}
+                onChange={(value: string) => {
+                  this.setState(prevState => {
+                    const namespaceData = prevState.namespaceOptions.get(prevState.createNamespace);
+                    const clusterUnits = namespaceData ? namespaceData.clusterUnits : {};
+                    const units = clusterUnits[value] || [];
+                    return {
+                      createCluster: value,
+                      createUnits: units,
+                      createUnit: units.length > 0 ? units[0] : '',
+                    };
+                  });
+                }}
+                dataSource={this.state.namespaceOptions.get(this.state.createNamespace)?.clusters.map(value => ({ label: value, value })) || []}
+                value={this.state.createCluster}
+              />
+            </FormItem>
+            {this.state.namespaceOptions.get(this.state.createNamespace)?.clusterTypes[this.state.createCluster] !== 'default' && (
+              <FormItem name="createUnit" label="Unit">
+                <Select
+                  placeholder="Select unit"
+                  onChange={(value: string) => {
+                    this.setState({ createUnit: value });
+                  }}
+                  dataSource={this.state.createUnits.map(value => ({ label: value, value }))}
+                  value={this.state.createUnit}
+                />
+              </FormItem>
+            )}
+            <FormItem name="vGroupName" label={vGroupNameLabel}>
+              <Input
+                placeholder={createVGroupInputPlaceholder}
+                value={this.state.vGroupName}
+                onChange={(value: string) => { this.setState({ vGroupName: value }); }}
+              />
+            </FormItem>
+            <FormItem>
+              <Button type="primary" onClick={this.handleCreateVGroup}>
+                {createVGroupConfirmButton}
+              </Button>
+            </FormItem>
+          </Form>
+        </Dialog>
+
+        {/* change vgroup dialog */}
+        <Dialog visible={this.state.changeVGroupDialogVisible} title={changeVGroupDialogTitle} footer={false} onClose={this.closeChangeVGroupDialog}>
+          <Form inline labelAlign="left">
+            <FormItem name="originalNamespace" label={originalNamespaceLabel}>
+              <Select
+                hasClear
+                placeholder={selectOriginalNamespacePlaceholder}
+                onChange={(value: string) => {
+                  this.setState(prevState => {
+                    const clusters = value ? prevState.namespaceOptions.get(value)?.clusters || [] : [];
+                    const firstCluster = clusters.length > 0 ? clusters[0] : '';
+                    const namespaceData = prevState.namespaceOptions.get(value);
+                    const clusterVgroups = namespaceData ? namespaceData.clusterVgroups : {};
+                    const vgroups = firstCluster ? clusterVgroups[firstCluster] || [] : [];
+                    return {
+                      originalNamespace: value,
+                      originalClusters: clusters,
+                      originalCluster: firstCluster,
+                      originalVGroups: vgroups,
+                    };
+                  });
+                }}
+                dataSource={Array.from(this.state.namespaceOptions.keys()).map(key => ({ label: key, value: key }))}
+                value={this.state.originalNamespace}
+              />
+            </FormItem>
+            <FormItem name="originalCluster" label={originalClusterLabel}>
+              <Select
+                hasClear
+                placeholder={selectOriginalClusterPlaceholder}
+                onChange={(value: string) => {
+                  this.setState(prevState => {
+                    const namespaceData = prevState.namespaceOptions.get(prevState.originalNamespace);
+                    const clusterVgroups = namespaceData ? namespaceData.clusterVgroups : {};
+                    const vgroups = clusterVgroups[value] || [];
+                    return {
+                      originalCluster: value,
+                      originalVGroups: vgroups,
+                    };
+                  });
+                }}
+                dataSource={this.state.originalClusters.map(value => ({ label: value, value }))}
+                value={this.state.originalCluster}
+              />
+            </FormItem>
+            <FormItem name="selectedVGroup" label={selectVGroupLabel}>
+              <Select
+                hasClear
+                placeholder={selectVGroupPlaceholder}
+                onChange={(value: string) => {
+                  this.setState({ selectedVGroup: value });
+                }}
+                dataSource={this.state.originalVGroups.map(value => ({ label: value, value }))}
+                value={this.state.selectedVGroup}
+              />
+            </FormItem>
+            <FormItem name="targetNamespace" label={targetNamespaceLabel}>
+              <Select
+                hasClear
+                placeholder={selectTargetNamespacePlaceholder}
+                onChange={(value: string) => {
+                  this.setState(prevState => {
+                    const clusters = value ? prevState.namespaceOptions.get(value)?.clusters || [] : [];
+                    return {
+                      targetNamespace: value,
+                      targetClusters: clusters,
+                      targetCluster: '',
+                      targetUnits: [],
+                      targetUnit: '',
+                    };
+                  });
+                }}
+                dataSource={Array.from(this.state.namespaceOptions.keys()).map(key => ({ label: key, value: key }))}
+                value={this.state.targetNamespace}
+              />
+            </FormItem>
+            <FormItem name="targetCluster" label={targetClusterLabel}>
+              <Select
+                hasClear
+                placeholder={selectTargetClusterPlaceholder}
+                onChange={(value: string) => {
+                  this.setState(prevState => {
+                    const namespaceData = prevState.namespaceOptions.get(prevState.targetNamespace);
+                    const clusterUnits = namespaceData ? namespaceData.clusterUnits : {};
+                    const units = clusterUnits[value] || [];
+                    return {
+                      targetCluster: value,
+                      targetUnits: units,
+                      targetUnit: units.length > 0 ? units[0] : '',
+                    };
+                  });
+                }}
+                dataSource={this.state.targetClusters.map(value => ({ label: value, value }))}
+                value={this.state.targetCluster}
+              />
+            </FormItem>
+            {this.state.targetCluster && this.state.namespaceOptions.get(this.state.targetNamespace)?.clusterTypes[this.state.targetCluster] !== 'default' && (
+              <FormItem name="targetUnit" label="Target Unit">
+                <Select
+                  hasClear
+                  placeholder="Select Target Unit"
+                  onChange={(value: string) => {
+                    this.setState({ targetUnit: value });
+                  }}
+                  dataSource={this.state.targetUnits.map(value => ({ label: value, value }))}
+                  value={this.state.targetUnit}
+                />
+              </FormItem>
+            )}
+            <FormItem>
+              <Button type="primary" onClick={this.handleChangeVGroup} disabled={this.isChangeVGroupDisabled()}>
+                {confirmButtonLabel}
+              </Button>
+            </FormItem>
+          </Form>
+        </Dialog>
       </Page>
     );
   }
 }
 
-export default withRouter(ConfigProvider.config(TransactionInfo, {}));
+const mapStateToProps = (state: any) => ({
+  locale: state.locale.locale,
+});
+
+export default ConfigProvider.config(withRouter(connect(mapStateToProps)(TransactionInfo)), {});
