@@ -18,10 +18,12 @@ import { HashRouter, Route, Switch, Redirect } from 'react-router-dom';
 import Overview from '@/pages/Overview';
 import TransactionInfo from '@/pages/TransactionInfo';
 import GlobalLockInfo from './pages/GlobalLockInfo';
+import ClusterManager from './pages/ClusterManager';
 
 export default [
   // { path: '/', exact: true, render: () => <Redirect to="/Overview" /> },
   // { path: '/Overview', component: Overview },
   { path: '/transaction/list', component: TransactionInfo },
   { path: '/globallock/list', component: GlobalLockInfo },
+  { path: '/cluster/list', component: ClusterManager },
 ];
