@@ -66,22 +66,24 @@ public class ServerOnResponseProcessor implements RemotingProcessor {
     @Override
     public void process(ChannelHandlerContext ctx, RpcMessage rpcMessage) throws Exception {
         MessageFuture messageFuture = futures.remove(rpcMessage.getId());
-        String receiveMsgLog = String.format(
-                "receive msg[single]: %s, clientIp: %s, vgroup: %s",
-                rpcMessage.getBody(),
-                NetUtil.toIpAddress(ctx.channel().remoteAddress()),
-                ChannelManager.getContextFromIdentified(ctx.channel()).getTransactionServiceGroup());
-        if (LOGGER.isInfoEnabled()) {
-            BatchLogHandler.INSTANCE.writeLog(receiveMsgLog);
-        }
+
         if (messageFuture != null) {
             messageFuture.setResultMessage(rpcMessage.getBody());
+            // Log only for registered channels to avoid NPE
+            if (ChannelManager.isRegistered(ctx.channel())) {
+                logReceivedMessage(ctx, rpcMessage);
+            }
         } else {
             if (ChannelManager.isRegistered(ctx.channel())) {
+                logReceivedMessage(ctx, rpcMessage);
                 onResponseMessage(ctx, rpcMessage);
             } else {
                 try {
                     ctx.disconnect();
+                } catch (Exception exx) {
+                    LOGGER.error(exx.getMessage());
+                }
+                try {
                     ctx.close();
                 } catch (Exception exx) {
                     LOGGER.error(exx.getMessage());
@@ -94,6 +96,18 @@ public class ServerOnResponseProcessor implements RemotingProcessor {
         }
     }
 
+    private void logReceivedMessage(ChannelHandlerContext ctx, RpcMessage rpcMessage) {
+        if (LOGGER.isInfoEnabled()) {
+            RpcContext rpcContext = ChannelManager.getContextFromIdentified(ctx.channel());
+            String receiveMsgLog = String.format(
+                    "receive msg[single]: %s, clientIp: %s, vgroup: %s",
+                    rpcMessage.getBody(),
+                    NetUtil.toIpAddress(ctx.channel().remoteAddress()),
+                    rpcContext != null ? rpcContext.getTransactionServiceGroup() : "unknown");
+            BatchLogHandler.INSTANCE.writeLog(receiveMsgLog);
+        }
+    }
+
     private void onResponseMessage(ChannelHandlerContext ctx, RpcMessage rpcMessage) {
         if (rpcMessage.getBody() instanceof AbstractResultMessage) {
             RpcContext rpcContext = ChannelManager.getContextFromIdentified(ctx.channel());
