@@ -17,5 +17,4 @@
 package org.apache.seata.integration.tx.api.remoting.parser;
 
 @RemoteBean
-public class SimpleRemoteBean {
-}
+public class SimpleRemoteBean {}
