@@ -19,16 +19,27 @@ package org.apache.seata.rm.datasource.undo;
 import org.apache.seata.common.loader.EnhancedServiceLoader;
 import org.apache.seata.common.util.CollectionUtils;
 import org.apache.seata.common.util.StringUtils;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
+import java.util.HashMap;
+import java.util.Map;
+import java.util.Objects;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 
 /**
  * The type Undo log parser factory.
- *
  */
 public class UndoLogParserFactory {
 
+    private static final Logger LOGGER = LoggerFactory.getLogger(UndoLogParserFactory.class);
+    private static final Map<String, String> SERIALIZER_ALIAS_MAP = new HashMap<>();
+
+    static {
+        SERIALIZER_ALIAS_MAP.put("fury", "fory");
+    }
+
     private UndoLogParserFactory() {}
 
     /**
@@ -58,9 +69,27 @@ public class UndoLogParserFactory {
     public static UndoLogParser getInstance(String name) {
         if (StringUtils.equalsIgnoreCase("fst", name)) {
             throw new IllegalArgumentException(
-                    "Since fst is no longer maintained, this serialization extension has been removed from version 2.0 for security and stability reasons.");
+                    "Since fst is no longer maintained, this serialization extension has been removed from version 2.0 "
+                            + "for security and stability reasons.");
+        }
+        String resolvedSerializerName = resolveSerializerName(name);
+        if (!Objects.equals(name, resolvedSerializerName)) {
+            LOGGER.info(
+                    "Since {} is no longer maintained, This serialization extension has been replaced with {}.",
+                    name,
+                    resolvedSerializerName);
         }
         return CollectionUtils.computeIfAbsent(
-                INSTANCES, name, key -> EnhancedServiceLoader.load(UndoLogParser.class, name));
+                INSTANCES, name, key -> EnhancedServiceLoader.load(UndoLogParser.class, resolvedSerializerName));
+    }
+
+    /**
+     * Resolve serializer name from alias mapping
+     *
+     * @param serializerName the original serializer name
+     * @return the resolved serializer name
+     */
+    private static String resolveSerializerName(String serializerName) {
+        return SERIALIZER_ALIAS_MAP.getOrDefault(serializerName.toLowerCase(), serializerName);
     }
 }
