@@ -16,12 +16,6 @@
  */
 package org.apache.seata.rm.datasource.xa;
 
-import java.util.Map;
-import java.util.concurrent.ScheduledExecutorService;
-import java.util.concurrent.ScheduledThreadPoolExecutor;
-import java.util.concurrent.TimeUnit;
-import java.sql.SQLException;
-import javax.transaction.xa.XAException;
 import org.apache.seata.common.DefaultValues;
 import org.apache.seata.common.lock.ResourceLock;
 import org.apache.seata.common.thread.NamedThreadFactory;
@@ -35,6 +29,13 @@ import org.apache.seata.rm.datasource.AbstractDataSourceCacheResourceManager;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import javax.transaction.xa.XAException;
+import java.sql.SQLException;
+import java.util.Map;
+import java.util.concurrent.ScheduledExecutorService;
+import java.util.concurrent.ScheduledThreadPoolExecutor;
+import java.util.concurrent.TimeUnit;
+
 import static org.apache.seata.core.constants.ConfigurationKeys.XA_CONNECTION_TWO_PHASE_HOLD_TIMEOUT;
 
 /**
@@ -45,8 +46,8 @@ public class ResourceManagerXA extends AbstractDataSourceCacheResourceManager {
 
     private static final Logger LOGGER = LoggerFactory.getLogger(ResourceManagerXA.class);
 
-    private static final int TWO_PHASE_HOLD_TIMEOUT = ConfigurationFactory.getInstance().getInt(XA_CONNECTION_TWO_PHASE_HOLD_TIMEOUT,
-            DefaultValues.DEFAULT_XA_CONNECTION_TWO_PHASE_HOLD_TIMEOUT);
+    private static final int TWO_PHASE_HOLD_TIMEOUT = ConfigurationFactory.getInstance()
+            .getInt(XA_CONNECTION_TWO_PHASE_HOLD_TIMEOUT, DefaultValues.DEFAULT_XA_CONNECTION_TWO_PHASE_HOLD_TIMEOUT);
 
     private static final long SCHEDULE_DELAY_MILLS = 60 * 1000L;
     private static final long SCHEDULE_INTERVAL_MILLS = 1000L;
@@ -54,6 +55,7 @@ public class ResourceManagerXA extends AbstractDataSourceCacheResourceManager {
      * The Timer check xa branch two phase hold timeout.
      */
     protected volatile ScheduledExecutorService xaTwoPhaseTimeoutChecker;
+
     private final ResourceLock resourceLock = new ResourceLock();
 
     @Override
@@ -65,39 +67,50 @@ public class ResourceManagerXA extends AbstractDataSourceCacheResourceManager {
         if (xaTwoPhaseTimeoutChecker == null) {
             try (ResourceLock ignored = resourceLock.obtain()) {
                 if (xaTwoPhaseTimeoutChecker == null) {
-                    boolean shouldBeHold = dataSourceCache.values().parallelStream().anyMatch(resource -> {
-                        if (resource instanceof DataSourceProxyXA) {
-                            return ((DataSourceProxyXA)resource).isShouldBeHeld();
-                        }
-                        return false;
-                    });
+                    boolean shouldBeHold = dataSourceCache.values().parallelStream()
+                            .anyMatch(resource -> {
+                                if (resource instanceof DataSourceProxyXA) {
+                                    return ((DataSourceProxyXA) resource).isShouldBeHeld();
+                                }
+                                return false;
+                            });
                     if (shouldBeHold) {
-                        xaTwoPhaseTimeoutChecker = new ScheduledThreadPoolExecutor(1,
-                            new NamedThreadFactory("xaTwoPhaseTimeoutChecker", 1, true));
-                        xaTwoPhaseTimeoutChecker.scheduleAtFixedRate(() -> {
-                            for (Map.Entry<String, Resource> entry : dataSourceCache.entrySet()) {
-                                BaseDataSourceResource resource = (BaseDataSourceResource)entry.getValue();
-                                if (resource.isShouldBeHeld()) {
-                                    if (resource instanceof DataSourceProxyXA) {
-                                        Map<String, ConnectionProxyXA> keeper = resource.getKeeper();
-                                        for (Map.Entry<String, ConnectionProxyXA> connectionEntry : keeper.entrySet()) {
-                                            ConnectionProxyXA connection = connectionEntry.getValue();
-                                            long now = System.currentTimeMillis();
-                                            try (ResourceLock ignored2 = connection.getResourceLock().obtain()) {
-                                                if (connection.getPrepareTime() != null
-                                                    && now - connection.getPrepareTime() > TWO_PHASE_HOLD_TIMEOUT) {
-                                                    try {
-                                                        connection.closeForce();
-                                                    } catch (SQLException e) {
-                                                        LOGGER.warn("Force close the xa physical connection fail", e);
+                        xaTwoPhaseTimeoutChecker = new ScheduledThreadPoolExecutor(
+                                1, new NamedThreadFactory("xaTwoPhaseTimeoutChecker", 1, true));
+                        xaTwoPhaseTimeoutChecker.scheduleAtFixedRate(
+                                () -> {
+                                    for (Map.Entry<String, Resource> entry : dataSourceCache.entrySet()) {
+                                        BaseDataSourceResource resource = (BaseDataSourceResource) entry.getValue();
+                                        if (resource.isShouldBeHeld()) {
+                                            if (resource instanceof DataSourceProxyXA) {
+                                                Map<String, ConnectionProxyXA> keeper = resource.getKeeper();
+                                                for (Map.Entry<String, ConnectionProxyXA> connectionEntry :
+                                                        keeper.entrySet()) {
+                                                    ConnectionProxyXA connection = connectionEntry.getValue();
+                                                    long now = System.currentTimeMillis();
+                                                    try (ResourceLock ignored2 = connection
+                                                            .getResourceLock()
+                                                            .obtain()) {
+                                                        if (connection.getPrepareTime() != null
+                                                                && now - connection.getPrepareTime()
+                                                                        > TWO_PHASE_HOLD_TIMEOUT) {
+                                                            try {
+                                                                connection.closeForce();
+                                                            } catch (SQLException e) {
+                                                                LOGGER.warn(
+                                                                        "Force close the xa physical connection fail",
+                                                                        e);
+                                                            }
+                                                        }
                                                     }
                                                 }
                                             }
                                         }
                                     }
-                                }
-                            }
-                        }, SCHEDULE_DELAY_MILLS, SCHEDULE_INTERVAL_MILLS, TimeUnit.MILLISECONDS);
+                                },
+                                SCHEDULE_DELAY_MILLS,
+                                SCHEDULE_INTERVAL_MILLS,
+                                TimeUnit.MILLISECONDS);
                     }
                 }
             }
@@ -110,24 +123,32 @@ public class ResourceManagerXA extends AbstractDataSourceCacheResourceManager {
     }
 
     @Override
-    public BranchStatus branchCommit(BranchType branchType, String xid, long branchId, String resourceId,
-                                     String applicationData) throws TransactionException {
+    public BranchStatus branchCommit(
+            BranchType branchType, String xid, long branchId, String resourceId, String applicationData)
+            throws TransactionException {
         return finishBranch(true, branchType, xid, branchId, resourceId, applicationData);
     }
 
     @Override
-    public BranchStatus branchRollback(BranchType branchType, String xid, long branchId, String resourceId,
-                                       String applicationData) throws TransactionException {
+    public BranchStatus branchRollback(
+            BranchType branchType, String xid, long branchId, String resourceId, String applicationData)
+            throws TransactionException {
         return finishBranch(false, branchType, xid, branchId, resourceId, applicationData);
     }
 
-    private BranchStatus finishBranch(boolean committed, BranchType branchType, String xid, long branchId, String resourceId,
-                                       String applicationData) throws TransactionException {
+    private BranchStatus finishBranch(
+            boolean committed,
+            BranchType branchType,
+            String xid,
+            long branchId,
+            String resourceId,
+            String applicationData)
+            throws TransactionException {
         XAXid xaBranchXid = XAXidBuilder.build(xid, branchId);
         Resource resource = dataSourceCache.get(resourceId);
         if (resource instanceof AbstractDataSourceProxyXA) {
             try (ConnectionProxyXA connectionProxyXA =
-                ((AbstractDataSourceProxyXA)resource).getConnectionForXAFinish(xaBranchXid)) {
+                    ((AbstractDataSourceProxyXA) resource).getConnectionForXAFinish(xaBranchXid)) {
                 if (committed) {
                     connectionProxyXA.xaCommit(xid, branchId, applicationData);
                     LOGGER.info(xaBranchXid + " was committed.");
@@ -148,7 +169,8 @@ public class ResourceManagerXA extends AbstractDataSourceCacheResourceManager {
                             }
                         }
                     } finally {
-                        BaseDataSourceResource.setBranchStatus(xaBranchXid.toString(),
+                        BaseDataSourceResource.setBranchStatus(
+                                xaBranchXid.toString(),
                                 committed ? BranchStatus.PhaseTwo_Committed : BranchStatus.PhaseTwo_Rollbacked);
                     }
                 }
