@@ -43,6 +43,7 @@ import java.io.CharArrayReader;
 import java.math.BigDecimal;
 import java.net.MalformedURLException;
 import java.net.URL;
+import java.sql.Connection;
 import java.sql.Date;
 import java.sql.JDBCType;
 import java.sql.PreparedStatement;
@@ -123,13 +124,15 @@ public class PreparedStatementProxyTest {
         dataSource.setDriver(mockDriver);
         DataSourceProxy dataSourceProxy = DataSourceProxyTest.getDataSourceProxy(dataSource);
 
-        ConnectionProxy connectionProxy =
-                new ConnectionProxy(dataSourceProxy, dataSource.getConnection().getConnection());
+        ConnectionProxy connectionProxy = new ConnectionProxy(dataSourceProxy, getPhysicsConnection(dataSource));
 
         String sql = "update prepared_statement_proxy set name = ?";
 
-        PreparedStatement preparedStatement = mockDriver.createSeataMockPreparedStatement(
-                (MockConnection) connectionProxy.getTargetConnection(), sql);
+        Connection targetConnection = connectionProxy.getTargetConnection();
+        targetConnection = targetConnection.unwrap(Connection.class);
+
+        PreparedStatement preparedStatement =
+                mockDriver.createSeataMockPreparedStatement((MockConnection) targetConnection, sql);
 
         preparedStatementProxy = new PreparedStatementProxy(connectionProxy, preparedStatement, sql);
         unusedConstructorPreparedStatementProxy =
@@ -142,6 +145,11 @@ public class PreparedStatementProxyTest {
                 EnhancedServiceLoader.load(SQLRecognizerFactory.class, SqlParserType.SQL_PARSER_TYPE_DRUID);
     }
 
+    private static Connection getPhysicsConnection(DruidDataSource dataSource) throws SQLException {
+        Connection connection = dataSource.getConnection().getConnection();
+        return connection.unwrap(Connection.class);
+    }
+
     @Test
     public void testPreparedStatementProxy() {
         Assertions.assertNotNull(preparedStatementProxy);
