@@ -37,6 +37,7 @@ import org.junit.jupiter.api.MethodOrderer;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.TestMethodOrder;
 
+import java.sql.Connection;
 import java.sql.SQLException;
 import java.sql.SQLFeatureNotSupportedException;
 import java.sql.Statement;
@@ -111,10 +112,11 @@ public class StatementProxyTest {
 
         DataSourceProxy dataSourceProxy = DataSourceProxyTest.getDataSourceProxy(dataSource);
 
-        ConnectionProxy connectionProxy =
-                new ConnectionProxy(dataSourceProxy, dataSource.getConnection().getConnection());
+        ConnectionProxy connectionProxy = new ConnectionProxy(dataSourceProxy, getPhysicsConnection(dataSource));
 
-        Statement statement = mockDriver.createMockStatement((MockConnection) connectionProxy.getTargetConnection());
+        Connection targetConnection = connectionProxy.getTargetConnection().unwrap(Connection.class);
+
+        Statement statement = mockDriver.createMockStatement((MockConnection) targetConnection);
 
         MockResultSet mockResultSet = new MockResultSet(statement);
         ((ResultSetMetaDataBase) mockResultSet.getMetaData())
@@ -131,6 +133,11 @@ public class StatementProxyTest {
                 EnhancedServiceLoader.load(SQLRecognizerFactory.class, SqlParserType.SQL_PARSER_TYPE_DRUID);
     }
 
+    private static Connection getPhysicsConnection(DruidDataSource dataSource) throws SQLException {
+        Connection connection = dataSource.getConnection().getConnection();
+        return connection.unwrap(Connection.class);
+    }
+
     @AfterEach
     public void clear() throws SQLException {
         statementProxy.clearBatch();
