@@ -19,8 +19,6 @@ package org.apache.seata.rm.datasource.exec;
 import com.alibaba.druid.mock.MockStatement;
 import com.alibaba.druid.mock.MockStatementBase;
 import com.alibaba.druid.pool.DruidDataSource;
-import com.alibaba.druid.sql.SQLUtils;
-import com.alibaba.druid.sql.ast.SQLStatement;
 import com.alibaba.druid.util.JdbcConstants;
 import com.google.common.collect.Lists;
 import org.apache.seata.rm.datasource.ConnectionProxy;
@@ -28,13 +26,14 @@ import org.apache.seata.rm.datasource.DataSourceProxy;
 import org.apache.seata.rm.datasource.DataSourceProxyTest;
 import org.apache.seata.rm.datasource.StatementProxy;
 import org.apache.seata.rm.datasource.mock.MockDriver;
+import org.apache.seata.rm.datasource.sql.SQLVisitorFactory;
 import org.apache.seata.rm.datasource.sql.struct.TableRecords;
-import org.apache.seata.sqlparser.druid.mysql.MySQLDeleteRecognizer;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 
 import java.lang.reflect.Field;
+import java.sql.Connection;
 import java.sql.SQLException;
 import java.sql.Types;
 import java.util.List;
@@ -108,31 +107,33 @@ public class DeleteExecutorTest {
             Field field = dataSourceProxy.getClass().getDeclaredField("dbType");
             field.setAccessible(true);
             field.set(dataSourceProxy, "mysql");
-            ConnectionProxy connectionProxy = new ConnectionProxy(
-                    dataSourceProxy, dataSource.getConnection().getConnection());
-            MockStatementBase mockStatement =
-                    new MockStatement(dataSource.getConnection().getConnection());
+            ConnectionProxy connectionProxy = new ConnectionProxy(dataSourceProxy, getPhysicsConnection(dataSource));
+            MockStatementBase mockStatement = new MockStatement(getPhysicsConnection(dataSource));
             statementProxy = new StatementProxy(connectionProxy, mockStatement);
         } catch (Exception e) {
             throw new RuntimeException("init failed");
         }
         String sql = "delete from table_delete_executor_test where id = 1";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, JdbcConstants.MYSQL);
-        MySQLDeleteRecognizer recognizer = new MySQLDeleteRecognizer(sql, asts.get(0));
         deleteExecutor = new DeleteExecutor(
                 statementProxy,
                 (statement, args) -> {
                     return null;
                 },
-                recognizer);
+                SQLVisitorFactory.get(sql, JdbcConstants.MYSQL.name()).get(0));
+    }
+
+    private static Connection getPhysicsConnection(DruidDataSource dataSource) throws SQLException {
+        Connection connection = dataSource.getConnection().getConnection();
+        return connection.unwrap(Connection.class);
     }
 
     @Test
     public void testBeforeAndAfterImage() throws SQLException {
         String sql = "delete from table_delete_executor_test";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, JdbcConstants.MYSQL);
-        MySQLDeleteRecognizer recognizer = new MySQLDeleteRecognizer(sql, asts.get(0));
-        deleteExecutor = new DeleteExecutor(statementProxy, (statement, args) -> null, recognizer);
+        deleteExecutor = new DeleteExecutor(
+                statementProxy,
+                (statement, args) -> null,
+                SQLVisitorFactory.get(sql, JdbcConstants.MYSQL.name()).get(0));
 
         TableRecords beforeImage = deleteExecutor.beforeImage();
         TableRecords afterImage = deleteExecutor.afterImage(beforeImage);
@@ -143,9 +144,10 @@ public class DeleteExecutorTest {
     @Test
     public void testBeforeAndAfterImageWithTableAlias() throws SQLException {
         String sql = "delete from table_delete_executor_test t where t.id = 1";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, JdbcConstants.MYSQL);
-        MySQLDeleteRecognizer recognizer = new MySQLDeleteRecognizer(sql, asts.get(0));
-        deleteExecutor = new DeleteExecutor(statementProxy, (statement, args) -> null, recognizer);
+        deleteExecutor = new DeleteExecutor(
+                statementProxy,
+                (statement, args) -> null,
+                SQLVisitorFactory.get(sql, JdbcConstants.MYSQL.name()).get(0));
 
         TableRecords beforeImage = deleteExecutor.beforeImage();
         TableRecords afterImage = deleteExecutor.afterImage(beforeImage);
@@ -156,9 +158,10 @@ public class DeleteExecutorTest {
     @Test
     public void testBeforeAndAfterImageWithTableSchema() throws SQLException {
         String sql = "delete from seata.table_delete_executor_test where id = 1";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, JdbcConstants.MYSQL);
-        MySQLDeleteRecognizer recognizer = new MySQLDeleteRecognizer(sql, asts.get(0));
-        deleteExecutor = new DeleteExecutor(statementProxy, (statement, args) -> null, recognizer);
+        deleteExecutor = new DeleteExecutor(
+                statementProxy,
+                (statement, args) -> null,
+                SQLVisitorFactory.get(sql, JdbcConstants.MYSQL.name()).get(0));
 
         TableRecords beforeImage = deleteExecutor.beforeImage();
         TableRecords afterImage = deleteExecutor.afterImage(beforeImage);
@@ -169,9 +172,10 @@ public class DeleteExecutorTest {
     @Test
     public void testBeforeAndAfterImageWithTableSchemaAndTableAlias() throws SQLException {
         String sql = "delete from seata.table_delete_executor_test t where t.id = 1";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, JdbcConstants.MYSQL);
-        MySQLDeleteRecognizer recognizer = new MySQLDeleteRecognizer(sql, asts.get(0));
-        deleteExecutor = new DeleteExecutor(statementProxy, (statement, args) -> null, recognizer);
+        deleteExecutor = new DeleteExecutor(
+                statementProxy,
+                (statement, args) -> null,
+                SQLVisitorFactory.get(sql, JdbcConstants.MYSQL.name()).get(0));
 
         TableRecords beforeImage = deleteExecutor.beforeImage();
         TableRecords afterImage = deleteExecutor.afterImage(beforeImage);
@@ -182,9 +186,10 @@ public class DeleteExecutorTest {
     @Test
     public void testBeforeAndAfterImageWithTableSchemaQuote() throws SQLException {
         String sql = "delete from `seata`.table_delete_executor_test where id = 1";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, JdbcConstants.MYSQL);
-        MySQLDeleteRecognizer recognizer = new MySQLDeleteRecognizer(sql, asts.get(0));
-        deleteExecutor = new DeleteExecutor(statementProxy, (statement, args) -> null, recognizer);
+        deleteExecutor = new DeleteExecutor(
+                statementProxy,
+                (statement, args) -> null,
+                SQLVisitorFactory.get(sql, JdbcConstants.MYSQL.name()).get(0));
 
         TableRecords beforeImage = deleteExecutor.beforeImage();
         TableRecords afterImage = deleteExecutor.afterImage(beforeImage);
@@ -195,9 +200,10 @@ public class DeleteExecutorTest {
     @Test
     public void testBeforeAndAfterImageWithTableSchemaAndTableNameQuote() throws SQLException {
         String sql = "delete from seata.`table_delete_executor_test` where id = 1";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, JdbcConstants.MYSQL);
-        MySQLDeleteRecognizer recognizer = new MySQLDeleteRecognizer(sql, asts.get(0));
-        deleteExecutor = new DeleteExecutor(statementProxy, (statement, args) -> null, recognizer);
+        deleteExecutor = new DeleteExecutor(
+                statementProxy,
+                (statement, args) -> null,
+                SQLVisitorFactory.get(sql, JdbcConstants.MYSQL.name()).get(0));
 
         TableRecords beforeImage = deleteExecutor.beforeImage();
         TableRecords afterImage = deleteExecutor.afterImage(beforeImage);
@@ -208,9 +214,10 @@ public class DeleteExecutorTest {
     @Test
     public void testBeforeAndAfterImageWithTableSchemaQuoteAndTableNameQuote() throws SQLException {
         String sql = "delete from `seata`.`table_delete_executor_test` where id = 1";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, JdbcConstants.MYSQL);
-        MySQLDeleteRecognizer recognizer = new MySQLDeleteRecognizer(sql, asts.get(0));
-        deleteExecutor = new DeleteExecutor(statementProxy, (statement, args) -> null, recognizer);
+        deleteExecutor = new DeleteExecutor(
+                statementProxy,
+                (statement, args) -> null,
+                SQLVisitorFactory.get(sql, JdbcConstants.MYSQL.name()).get(0));
 
         TableRecords beforeImage = deleteExecutor.beforeImage();
         TableRecords afterImage = deleteExecutor.afterImage(beforeImage);
@@ -221,9 +228,10 @@ public class DeleteExecutorTest {
     @Test
     public void testBeforeAndAfterImageWithColumnQuote() throws SQLException {
         String sql = "delete from table_delete_executor_test where `id` = 1";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, JdbcConstants.MYSQL);
-        MySQLDeleteRecognizer recognizer = new MySQLDeleteRecognizer(sql, asts.get(0));
-        deleteExecutor = new DeleteExecutor(statementProxy, (statement, args) -> null, recognizer);
+        deleteExecutor = new DeleteExecutor(
+                statementProxy,
+                (statement, args) -> null,
+                SQLVisitorFactory.get(sql, JdbcConstants.MYSQL.name()).get(0));
 
         TableRecords beforeImage = deleteExecutor.beforeImage();
         TableRecords afterImage = deleteExecutor.afterImage(beforeImage);
@@ -234,9 +242,10 @@ public class DeleteExecutorTest {
     @Test
     public void testBeforeAndAfterImageWithUpperColumn() throws SQLException {
         String sql = "delete from table_delete_executor_test where ID = 1";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, JdbcConstants.MYSQL);
-        MySQLDeleteRecognizer recognizer = new MySQLDeleteRecognizer(sql, asts.get(0));
-        deleteExecutor = new DeleteExecutor(statementProxy, (statement, args) -> null, recognizer);
+        deleteExecutor = new DeleteExecutor(
+                statementProxy,
+                (statement, args) -> null,
+                SQLVisitorFactory.get(sql, JdbcConstants.MYSQL.name()).get(0));
 
         TableRecords beforeImage = deleteExecutor.beforeImage();
         TableRecords afterImage = deleteExecutor.afterImage(beforeImage);
@@ -247,9 +256,11 @@ public class DeleteExecutorTest {
     @Test
     public void testBeforeAndAfterImageWithTableAliasAndUpperColumn() throws SQLException {
         String sql = "delete from table_delete_executor_test t where t.ID = 1";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, JdbcConstants.MYSQL);
-        MySQLDeleteRecognizer recognizer = new MySQLDeleteRecognizer(sql, asts.get(0));
-        deleteExecutor = new DeleteExecutor(statementProxy, (statement, args) -> null, recognizer);
+
+        deleteExecutor = new DeleteExecutor(
+                statementProxy,
+                (statement, args) -> null,
+                SQLVisitorFactory.get(sql, JdbcConstants.MYSQL.name()).get(0));
 
         TableRecords beforeImage = deleteExecutor.beforeImage();
         TableRecords afterImage = deleteExecutor.afterImage(beforeImage);
@@ -260,9 +271,10 @@ public class DeleteExecutorTest {
     @Test
     public void testBeforeAndAfterImageWithKeyword() throws SQLException {
         String sql = "delete from table_delete_executor_test where `or` = 1";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, JdbcConstants.MYSQL);
-        MySQLDeleteRecognizer recognizer = new MySQLDeleteRecognizer(sql, asts.get(0));
-        deleteExecutor = new DeleteExecutor(statementProxy, (statement, args) -> null, recognizer);
+        deleteExecutor = new DeleteExecutor(
+                statementProxy,
+                (statement, args) -> null,
+                SQLVisitorFactory.get(sql, JdbcConstants.MYSQL.name()).get(0));
 
         TableRecords beforeImage = deleteExecutor.beforeImage();
         TableRecords afterImage = deleteExecutor.afterImage(beforeImage);
