@@ -51,6 +51,7 @@ import java.lang.reflect.Field;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.math.BigDecimal;
+import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
@@ -249,16 +250,20 @@ public class MySQLInsertExecutorTest {
             Field field = dataSourceProxy.getClass().getDeclaredField("dbType");
             field.setAccessible(true);
             field.set(newDataSourceProxy, "mysql");
-            ConnectionProxy newConnectionProxy = new ConnectionProxy(
-                    newDataSourceProxy, dataSource.getConnection().getConnection());
-            MockStatementBase mockStatement =
-                    new MockStatement(dataSource.getConnection().getConnection());
+            ConnectionProxy newConnectionProxy =
+                    new ConnectionProxy(newDataSourceProxy, getPhysicsConnection(dataSource));
+            MockStatementBase mockStatement = new MockStatement(getPhysicsConnection(dataSource));
             newStatementProxy = new StatementProxy(newConnectionProxy, mockStatement);
         } catch (Exception e) {
             throw new RuntimeException("init failed");
         }
     }
 
+    protected static Connection getPhysicsConnection(DruidDataSource dataSource) throws SQLException {
+        Connection connection = dataSource.getConnection().getConnection();
+        return connection.unwrap(Connection.class);
+    }
+
     @Test
     public void testBeforeAndAfterImage() throws SQLException {
         System.out.println(newStatementProxy);
@@ -827,7 +832,7 @@ public class MySQLInsertExecutorTest {
     }
 
     private void mockParameters() {
-        Map<Integer, ArrayList<Object>> paramters = new HashMap<>(4);
+        Map<Integer, ArrayList<Object>> parameters = new HashMap<>(4);
         ArrayList arrayList0 = new ArrayList<>();
         arrayList0.add(PK_VALUE);
         ArrayList arrayList1 = new ArrayList<>();
@@ -836,12 +841,12 @@ public class MySQLInsertExecutorTest {
         arrayList2.add("userName1");
         ArrayList arrayList3 = new ArrayList<>();
         arrayList3.add("userStatus1");
-        paramters.put(1, arrayList0);
-        paramters.put(2, arrayList1);
-        paramters.put(3, arrayList2);
-        paramters.put(4, arrayList3);
+        parameters.put(1, arrayList0);
+        parameters.put(2, arrayList1);
+        parameters.put(3, arrayList2);
+        parameters.put(4, arrayList3);
         PreparedStatementProxy psp = (PreparedStatementProxy) this.statementProxy;
-        when(psp.getParameters()).thenReturn(paramters);
+        when(psp.getParameters()).thenReturn(parameters);
     }
 
     private void mockParametersPkWithNull() {
@@ -863,12 +868,12 @@ public class MySQLInsertExecutorTest {
     }
 
     private void mockParametersOfOnePk() {
-        Map<Integer, ArrayList<Object>> paramters = new HashMap<>(4);
+        Map<Integer, ArrayList<Object>> parameters = new HashMap<>(4);
         ArrayList arrayList1 = new ArrayList<>();
         arrayList1.add(PK_VALUE);
-        paramters.put(1, arrayList1);
+        parameters.put(1, arrayList1);
         PreparedStatementProxy psp = (PreparedStatementProxy) this.statementProxy;
-        when(psp.getParameters()).thenReturn(paramters);
+        when(psp.getParameters()).thenReturn(parameters);
     }
 
     private void mockInsertRows() {
