@@ -215,8 +215,7 @@ public class OscarInsertExecutorTest {
         List<String> columns = new ArrayList<>();
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(columns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(true);
-        Assertions.assertIterableEquals(
-                mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertEquals(mockPkValuesFromColumn, insertExecutor.getPkValues());
 
         // situation2: insert columns contain the pk column
         columns = new ArrayList<>();
@@ -224,17 +223,15 @@ public class OscarInsertExecutorTest {
         columns.add(USER_NAME_COLUMN);
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(columns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(false);
-        Assertions.assertIterableEquals(
-                mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertEquals(mockPkValuesFromColumn, insertExecutor.getPkValues());
 
         // situation3: insert columns are not empty and do not contain the pk column
         columns = new ArrayList<>();
         columns.add(USER_NAME_COLUMN);
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(columns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(false);
-        Assertions.assertIterableEquals(
-                Collections.singletonMap(ID_COLUMN, mockPkValuesAutoGenerated).entrySet(),
-                insertExecutor.getPkValues().entrySet());
+        Assertions.assertEquals(
+                Collections.singletonMap(ID_COLUMN, mockPkValuesAutoGenerated), insertExecutor.getPkValues());
     }
 
     @Test
@@ -262,9 +259,7 @@ public class OscarInsertExecutorTest {
         List<String> insertColumns = new ArrayList<>();
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(insertColumns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(true);
-        Assertions.assertIterableEquals(
-                mockAllPkValuesFromColumn.entrySet(),
-                insertExecutor.getPkValues().entrySet());
+        Assertions.assertEquals(mockAllPkValuesFromColumn, insertExecutor.getPkValues());
 
         // situation2: insert columns contain all pk columns
         insertColumns = new ArrayList<>();
@@ -273,9 +268,7 @@ public class OscarInsertExecutorTest {
         insertColumns.add(USER_NAME_COLUMN);
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(insertColumns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(false);
-        Assertions.assertIterableEquals(
-                mockAllPkValuesFromColumn.entrySet(),
-                insertExecutor.getPkValues().entrySet());
+        Assertions.assertEquals(mockAllPkValuesFromColumn, insertExecutor.getPkValues());
 
         // situation3: insert columns contain partial pk columns
         insertColumns = new ArrayList<>();
@@ -290,8 +283,7 @@ public class OscarInsertExecutorTest {
 
         Map<String, List<Object>> expectPkValues = new HashMap<>(mockPkValuesFromColumn_ID);
         expectPkValues.put(USER_ID_COLUMN, mockPkValuesAutoGenerated_USER_ID);
-        Assertions.assertIterableEquals(
-                expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertEquals(expectPkValues, insertExecutor.getPkValues());
 
         // situation4: insert columns are not empty and do not contain the pk column
         insertColumns = new ArrayList<>();
@@ -304,8 +296,7 @@ public class OscarInsertExecutorTest {
         expectPkValues = new HashMap<>();
         expectPkValues.put(ID_COLUMN, mockPkValuesAutoGenerated_ID);
         expectPkValues.put(USER_ID_COLUMN, mockPkValuesAutoGenerated_USER_ID);
-        Assertions.assertIterableEquals(
-                expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertEquals(expectPkValues, insertExecutor.getPkValues());
     }
 
     @Test
@@ -353,7 +344,7 @@ public class OscarInsertExecutorTest {
 
     private SqlSequenceExpr mockParametersPkWithSeq() {
         SqlSequenceExpr expr = new SqlSequenceExpr("seq", "nextval");
-        Map<Integer, ArrayList<Object>> paramters = new HashMap(4);
+        Map<Integer, ArrayList<Object>> parameters = new HashMap(4);
         ArrayList arrayList0 = new ArrayList<>();
         arrayList0.add(expr);
         ArrayList arrayList1 = new ArrayList<>();
@@ -362,12 +353,12 @@ public class OscarInsertExecutorTest {
         arrayList2.add("userName1");
         ArrayList arrayList3 = new ArrayList<>();
         arrayList3.add("userStatus1");
-        paramters.put(1, arrayList0);
-        paramters.put(2, arrayList1);
-        paramters.put(3, arrayList2);
-        paramters.put(4, arrayList3);
+        parameters.put(1, arrayList0);
+        parameters.put(2, arrayList1);
+        parameters.put(3, arrayList2);
+        parameters.put(4, arrayList3);
         PreparedStatementProxy psp = (PreparedStatementProxy) this.statementProxy;
-        when(psp.getParameters()).thenReturn(paramters);
+        when(psp.getParameters()).thenReturn(parameters);
 
         List<List<Object>> rows = new ArrayList<>();
         rows.add(Arrays.asList("?", "?", "?"));
@@ -378,7 +369,7 @@ public class OscarInsertExecutorTest {
 
     private SqlSequenceExpr mockParametersMultiPkWithSeq() {
         SqlSequenceExpr expr = new SqlSequenceExpr("seq", "nextval");
-        Map<Integer, ArrayList<Object>> paramters = new HashMap(4);
+        Map<Integer, ArrayList<Object>> parameters = new HashMap(4);
         ArrayList arrayList0 = new ArrayList<>();
         arrayList0.add(expr);
         ArrayList arrayList1 = new ArrayList<>();
@@ -387,12 +378,12 @@ public class OscarInsertExecutorTest {
         arrayList2.add("userName1");
         ArrayList arrayList3 = new ArrayList<>();
         arrayList3.add("userStatus1");
-        paramters.put(1, arrayList0);
-        paramters.put(2, arrayList1);
-        paramters.put(3, arrayList2);
-        paramters.put(4, arrayList3);
+        parameters.put(1, arrayList0);
+        parameters.put(2, arrayList1);
+        parameters.put(3, arrayList2);
+        parameters.put(4, arrayList3);
         PreparedStatementProxy psp = (PreparedStatementProxy) this.statementProxy;
-        when(psp.getParameters()).thenReturn(paramters);
+        when(psp.getParameters()).thenReturn(parameters);
 
         List<List<Object>> rows = new ArrayList<>();
         rows.add(Arrays.asList("?", "?"));
@@ -402,7 +393,7 @@ public class OscarInsertExecutorTest {
     }
 
     private void mockParametersPkWithAuto() {
-        Map<Integer, ArrayList<Object>> paramters = new HashMap<>(4);
+        Map<Integer, ArrayList<Object>> parameters = new HashMap<>(4);
         ArrayList arrayList0 = new ArrayList<>();
         arrayList0.add(Null.get());
         ArrayList arrayList1 = new ArrayList<>();
@@ -411,12 +402,12 @@ public class OscarInsertExecutorTest {
         arrayList2.add("userName1");
         ArrayList arrayList3 = new ArrayList<>();
         arrayList3.add("userStatus1");
-        paramters.put(1, arrayList0);
-        paramters.put(2, arrayList1);
-        paramters.put(3, arrayList2);
-        paramters.put(4, arrayList3);
+        parameters.put(1, arrayList0);
+        parameters.put(2, arrayList1);
+        parameters.put(3, arrayList2);
+        parameters.put(4, arrayList3);
         PreparedStatementProxy psp = (PreparedStatementProxy) this.statementProxy;
-        when(psp.getParameters()).thenReturn(paramters);
+        when(psp.getParameters()).thenReturn(parameters);
 
         List<List<Object>> rows = new ArrayList<>();
         rows.add(Arrays.asList("?", "?", "?", "?"));
@@ -424,7 +415,7 @@ public class OscarInsertExecutorTest {
     }
 
     private void mockParametersMultiPkWithAuto() {
-        Map<Integer, ArrayList<Object>> paramters = new HashMap<>(4);
+        Map<Integer, ArrayList<Object>> parameters = new HashMap<>(4);
         ArrayList arrayList0 = new ArrayList<>();
         arrayList0.add(Null.get());
         ArrayList arrayList1 = new ArrayList<>();
@@ -433,12 +424,12 @@ public class OscarInsertExecutorTest {
         arrayList2.add("userName1");
         ArrayList arrayList3 = new ArrayList<>();
         arrayList3.add("userStatus1");
-        paramters.put(1, arrayList0);
-        paramters.put(2, arrayList1);
-        paramters.put(3, arrayList2);
-        paramters.put(4, arrayList3);
+        parameters.put(1, arrayList0);
+        parameters.put(2, arrayList1);
+        parameters.put(3, arrayList2);
+        parameters.put(4, arrayList3);
         PreparedStatementProxy psp = (PreparedStatementProxy) this.statementProxy;
-        when(psp.getParameters()).thenReturn(paramters);
+        when(psp.getParameters()).thenReturn(parameters);
 
         List<List<Object>> rows = new ArrayList<>();
         rows.add(Arrays.asList("?", "?", "?", "?"));
