@@ -28,6 +28,7 @@ import org.apache.seata.rm.datasource.mock.MockDriver;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
+import java.sql.Connection;
 import java.sql.SQLException;
 import java.sql.Types;
 import java.util.List;
@@ -96,15 +97,18 @@ public class PlainExecutorTest {
 
         DataSourceProxy dataSourceProxy = DataSourceProxyTest.getDataSourceProxy(dataSource);
 
-        ConnectionProxy connectionProxy =
-                new ConnectionProxy(dataSourceProxy, dataSource.getConnection().getConnection());
-        MockStatementBase mockStatement =
-                new MockStatement(dataSource.getConnection().getConnection());
+        ConnectionProxy connectionProxy = new ConnectionProxy(dataSourceProxy, getPhysicsConnection(dataSource));
+        MockStatementBase mockStatement = new MockStatement(getPhysicsConnection(dataSource));
         StatementProxy statementProxy = new StatementProxy(connectionProxy, mockStatement);
 
         plainExecutor = new PlainExecutor(statementProxy, (statement, args) -> null);
     }
 
+    private Connection getPhysicsConnection(DruidDataSource dataSource) throws SQLException {
+        Connection connection = dataSource.getConnection().getConnection();
+        return connection.unwrap(Connection.class);
+    }
+
     @Test
     public void testExecute() throws Throwable {
         plainExecutor.execute((Object) null);
