@@ -171,8 +171,7 @@ public class PostgresqlInsertExecutorTest {
         List<String> columns = new ArrayList<>();
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(columns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(true);
-        Assertions.assertIterableEquals(
-                mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertEquals(mockPkValuesFromColumn, insertExecutor.getPkValues());
 
         // situation2: insert columns contain the pk column
         columns = new ArrayList<>();
@@ -180,17 +179,15 @@ public class PostgresqlInsertExecutorTest {
         columns.add(USER_NAME_COLUMN);
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(columns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(false);
-        Assertions.assertIterableEquals(
-                mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertEquals(mockPkValuesFromColumn, insertExecutor.getPkValues());
 
         // situation3: insert columns are not empty and do not contain the pk column
         columns = new ArrayList<>();
         columns.add(USER_NAME_COLUMN);
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(columns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(false);
-        Assertions.assertIterableEquals(
-                Collections.singletonMap(ID_COLUMN, mockPkValuesAutoGenerated).entrySet(),
-                insertExecutor.getPkValues().entrySet());
+        Assertions.assertEquals(
+                Collections.singletonMap(ID_COLUMN, mockPkValuesAutoGenerated), insertExecutor.getPkValues());
     }
 
     @Test
@@ -218,9 +215,7 @@ public class PostgresqlInsertExecutorTest {
         List<String> insertColumns = new ArrayList<>();
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(insertColumns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(true);
-        Assertions.assertIterableEquals(
-                mockAllPkValuesFromColumn.entrySet(),
-                insertExecutor.getPkValues().entrySet());
+        Assertions.assertEquals(mockAllPkValuesFromColumn, insertExecutor.getPkValues());
 
         // situation2: insert columns contain all pk columns
         insertColumns = new ArrayList<>();
@@ -229,9 +224,7 @@ public class PostgresqlInsertExecutorTest {
         insertColumns.add(USER_NAME_COLUMN);
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(insertColumns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(false);
-        Assertions.assertIterableEquals(
-                mockAllPkValuesFromColumn.entrySet(),
-                insertExecutor.getPkValues().entrySet());
+        Assertions.assertEquals(mockAllPkValuesFromColumn, insertExecutor.getPkValues());
 
         // situation3: insert columns contain partial pk columns
         insertColumns = new ArrayList<>();
@@ -246,8 +239,7 @@ public class PostgresqlInsertExecutorTest {
 
         Map<String, List<Object>> expectPkValues = new HashMap<>(mockPkValuesFromColumn_ID);
         expectPkValues.put(USER_ID_COLUMN, mockPkValuesAutoGenerated_USER_ID);
-        Assertions.assertIterableEquals(
-                expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertEquals(expectPkValues, insertExecutor.getPkValues());
 
         // situation4: insert columns are not empty and do not contain the pk column
         insertColumns = new ArrayList<>();
@@ -260,8 +252,7 @@ public class PostgresqlInsertExecutorTest {
         expectPkValues = new HashMap<>();
         expectPkValues.put(ID_COLUMN, mockPkValuesAutoGenerated_ID);
         expectPkValues.put(USER_ID_COLUMN, mockPkValuesAutoGenerated_USER_ID);
-        Assertions.assertIterableEquals(
-                expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertEquals(expectPkValues, insertExecutor.getPkValues());
     }
 
     @Test
