@@ -36,6 +36,8 @@ import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 
 import java.lang.reflect.Field;
+import java.sql.Connection;
+import java.sql.SQLException;
 import java.sql.Types;
 import java.util.List;
 
@@ -112,11 +114,9 @@ public class SelectForUpdateExecutorTest {
             Field field = dataSourceProxy.getClass().getDeclaredField("dbType");
             field.setAccessible(true);
             field.set(dataSourceProxy, "mysql");
-            connectionProxy = new MockConnectionProxy(
-                    dataSourceProxy, dataSource.getConnection().getConnection());
+            connectionProxy = new MockConnectionProxy(dataSourceProxy, getPhysicsConnection(dataSource));
             connectionProxy.bind("xid");
-            MockStatement mockStatement =
-                    new MockStatement(dataSource.getConnection().getConnection());
+            MockStatement mockStatement = new MockStatement(getPhysicsConnection(dataSource));
             statementProxy = new StatementProxy(connectionProxy, mockStatement);
         } catch (Exception e) {
             throw new RuntimeException("init failed");
@@ -133,6 +133,11 @@ public class SelectForUpdateExecutorTest {
                 recognizer);
     }
 
+    private static Connection getPhysicsConnection(DruidDataSource dataSource) throws SQLException {
+        Connection connection = dataSource.getConnection().getConnection();
+        return connection.unwrap(Connection.class);
+    }
+
     @Test
     public void testDoExecute() throws Throwable {
         Assertions.assertThrows(RuntimeException.class, () -> selectForUpdateExecutor.doExecute((Object) null));
