@@ -17,6 +17,8 @@
 package org.apache.seata.rm.datasource.sql.struct;
 
 import org.apache.seata.common.loader.EnhancedServiceNotFoundException;
+import org.apache.seata.rm.datasource.DataSourceProxy;
+import org.apache.seata.rm.datasource.mock.MockDataSource;
 import org.apache.seata.rm.datasource.sql.struct.cache.MariadbTableMetaCache;
 import org.apache.seata.rm.datasource.sql.struct.cache.MysqlTableMetaCache;
 import org.apache.seata.rm.datasource.sql.struct.cache.OceanBaseTableMetaCache;
@@ -24,12 +26,24 @@ import org.apache.seata.rm.datasource.sql.struct.cache.OracleTableMetaCache;
 import org.apache.seata.rm.datasource.sql.struct.cache.PolarDBXTableMetaCache;
 import org.apache.seata.sqlparser.util.JdbcConstants;
 import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
+import java.lang.reflect.Field;
+import java.util.Map;
+
 public class TableMetaCacheFactoryTest {
 
     private static final String NOT_EXIST_SQL_TYPE = "not_exist_sql_type";
 
+    @BeforeEach
+    public void clearTableMetaRefreshHolderMap() throws Exception {
+        Field field = TableMetaCacheFactory.class.getDeclaredField("TABLE_META_REFRESH_HOLDER_MAP");
+        field.setAccessible(true);
+        Map<?, ?> map = (Map<?, ?>) field.get(null);
+        map.clear();
+    }
+
     @Test
     public void getTableMetaCache() {
         Assertions.assertTrue(
@@ -52,4 +66,23 @@ public class TableMetaCacheFactoryTest {
             TableMetaCacheFactory.getTableMetaCache(NOT_EXIST_SQL_TYPE);
         });
     }
+
+    @Test
+    public void shutdownTest() throws NoSuchFieldException, IllegalAccessException {
+        DataSourceProxy dummy = new DataSourceProxy(new MockDataSource(), "dummy1");
+        TableMetaCacheFactory.registerTableMeta(dummy);
+
+        Map<String, TableMetaCacheFactory.TableMetaRefreshHolder> holderMap = getTableMetaRefreshHolderMap();
+        Assertions.assertEquals(1, holderMap.size());
+
+        TableMetaCacheFactory.shutdown("jdbc:mysql://127.0.0.1:3306/seata");
+        Assertions.assertTrue(holderMap.isEmpty(), "TableMetaRefreshHolder map should be empty after shutdown");
+    }
+
+    private Map<String, TableMetaCacheFactory.TableMetaRefreshHolder> getTableMetaRefreshHolderMap()
+            throws NoSuchFieldException, IllegalAccessException {
+        Field field = TableMetaCacheFactory.class.getDeclaredField("TABLE_META_REFRESH_HOLDER_MAP");
+        field.setAccessible(true);
+        return (Map<String, TableMetaCacheFactory.TableMetaRefreshHolder>) field.get(null);
+    }
 }
