@@ -19,21 +19,31 @@ package org.apache.seata.rm.datasource.sql.struct;
 import com.alibaba.druid.mock.MockStatement;
 import com.alibaba.druid.mock.MockStatementBase;
 import com.alibaba.druid.pool.DruidDataSource;
+import com.fasterxml.jackson.databind.DeserializationFeature;
+import com.fasterxml.jackson.databind.ObjectMapper;
+import com.fasterxml.jackson.datatype.jsr310.JavaTimeModule;
 import com.google.common.collect.Lists;
 import org.apache.seata.common.exception.ShouldNeverHappenException;
 import org.apache.seata.rm.datasource.DataSourceProxy;
 import org.apache.seata.rm.datasource.DataSourceProxyTest;
 import org.apache.seata.rm.datasource.exception.TableMetaException;
 import org.apache.seata.rm.datasource.mock.MockDriver;
+import org.apache.seata.sqlparser.struct.ColumnMeta;
+import org.apache.seata.sqlparser.struct.IndexMeta;
+import org.apache.seata.sqlparser.struct.IndexType;
 import org.apache.seata.sqlparser.struct.TableMeta;
 import org.apache.seata.sqlparser.util.JdbcConstants;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
+import java.io.IOException;
+import java.sql.Connection;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Types;
+import java.time.OffsetDateTime;
+import java.time.ZoneOffset;
 import java.util.List;
 
 /**
@@ -218,8 +228,7 @@ public class TableRecordsTest {
         dataSource.setUrl("jdbc:mock:xxx");
         dataSource.setDriver(mockDriver);
 
-        MockStatementBase mockStatement =
-                new MockStatement(dataSource.getConnection().getConnection());
+        MockStatementBase mockStatement = new MockStatement(getPhysicsConnection(dataSource));
         DataSourceProxy proxy = DataSourceProxyTest.getDataSourceProxy(dataSource);
 
         TableMeta tableMeta = TableMetaCacheFactory.getTableMetaCache(JdbcConstants.MYSQL)
@@ -232,14 +241,18 @@ public class TableRecordsTest {
         Assertions.assertEquals(returnValue.length, tableRecords.pkRows().size());
     }
 
+    private Connection getPhysicsConnection(DruidDataSource dataSource) throws SQLException {
+        Connection connection = dataSource.getConnection().getConnection();
+        return connection.unwrap(Connection.class);
+    }
+
     @Test
     public void testBuildRecords() throws SQLException {
         MockDriver mockDriver = new MockDriver(returnValueColumnLabels, returnValue, columnMetas, indexMetas);
         DruidDataSource dataSource = new DruidDataSource();
         dataSource.setUrl("jdbc:mock:xxx");
         dataSource.setDriver(mockDriver);
-        MockStatementBase mockStatement =
-                new MockStatement(dataSource.getConnection().getConnection());
+        MockStatementBase mockStatement = new MockStatement(getPhysicsConnection(dataSource));
         DataSourceProxy proxy = DataSourceProxyTest.getDataSourceProxy(dataSource);
 
         TableMeta tableMeta = TableMetaCacheFactory.getTableMetaCache(JdbcConstants.MYSQL)
@@ -258,8 +271,7 @@ public class TableRecordsTest {
         DruidDataSource dataSource = new DruidDataSource();
         dataSource.setUrl("jdbc:mock:xxx");
         dataSource.setDriver(mockDriver);
-        MockStatementBase mockStatement =
-                new MockStatement(dataSource.getConnection().getConnection());
+        MockStatementBase mockStatement = new MockStatement(getPhysicsConnection(dataSource));
         DataSourceProxy proxy = DataSourceProxyTest.getDataSourceProxy(dataSource);
 
         TableMeta tableMeta = TableMetaCacheFactory.getTableMetaCache(JdbcConstants.MYSQL)
@@ -285,4 +297,110 @@ public class TableRecordsTest {
         Assertions.assertThrows(UnsupportedOperationException.class, () -> empty.add(new Row()));
         Assertions.assertThrows(UnsupportedOperationException.class, empty::getTableMeta);
     }
+
+    private static Object[][] columnMetasOffsetDateTime = new Object[][] {
+        new Object[] {
+            "", "", "table_records_test", "id", Types.INTEGER, "INTEGER", 64, 0, 10, 1, "", "", 0, 0, 64, 1, "NO", "YES"
+        },
+        new Object[] {
+            "",
+            "",
+            "table_records_test",
+            "time_col",
+            Types.TIMESTAMP_WITH_TIMEZONE,
+            "TIMESTAMP_WITH_TIMEZONE",
+            64,
+            0,
+            10,
+            0,
+            "",
+            "",
+            0,
+            0,
+            64,
+            2,
+            "YES",
+            "NO"
+        },
+    };
+
+    private static List<String> returnValueColumnLabelsOffsetDateTime = Lists.newArrayList("id", "time_col");
+
+    private static Object[][] returnValueOffsetDateTime = new Object[][] {
+        new Object[] {1, OffsetDateTime.of(2025, 1, 15, 10, 30, 45, 0, ZoneOffset.UTC)},
+    };
+
+    @Test
+    public void testBuildRecordsWithOffsetDateTime() throws SQLException, IOException {
+        MockDriver mockDriver = new MockDriver(
+                returnValueColumnLabelsOffsetDateTime,
+                returnValueOffsetDateTime,
+                columnMetasOffsetDateTime,
+                indexMetas);
+
+        DruidDataSource dataSource = new DruidDataSource();
+        dataSource.setUrl("jdbc:mock:offset");
+        dataSource.setDriver(mockDriver);
+
+        try (MockStatementBase mockStatement = new MockStatement(getPhysicsConnection(dataSource))) {
+            DataSourceProxy proxy = DataSourceProxyTest.getDataSourceProxy(dataSource);
+            TableMetaCacheFactory.getTableMetaCache(JdbcConstants.POSTGRESQL)
+                    .refresh(proxy.getPlainConnection(), proxy.getResourceId());
+            TableMeta tableMeta = TableMetaCacheFactory.getTableMetaCache(JdbcConstants.POSTGRESQL)
+                    .getTableMeta(proxy.getPlainConnection(), "table_records_test", proxy.getResourceId());
+            ColumnMeta idColumnMeta = new ColumnMeta();
+            idColumnMeta.setColumnName("id");
+            idColumnMeta.setDataType(java.sql.Types.INTEGER);
+            idColumnMeta.setTableName("table_records_test");
+            idColumnMeta.setIsAutoincrement("NO");
+            idColumnMeta.setIsNullAble("NO");
+
+            IndexMeta primaryIndex = new IndexMeta();
+            primaryIndex.setIndexName("PRIMARY");
+            primaryIndex.setIndextype(IndexType.PRIMARY);
+            primaryIndex.getValues().add(idColumnMeta);
+
+            tableMeta.getAllIndexes().put("PRIMARY", primaryIndex);
+            if (tableMeta.getColumnMeta("id") == null) {
+                tableMeta.getAllColumns().put("id", idColumnMeta);
+            }
+            ResultSet originalResultSet = mockDriver.executeQuery(mockStatement, "select * from table_records_test");
+            ResultSet proxyResultSet = (ResultSet) java.lang.reflect.Proxy.newProxyInstance(
+                    TableRecordsTest.class.getClassLoader(), new Class[] {ResultSet.class}, (p, method, args) -> {
+                        if ("getObject".equals(method.getName())
+                                && args.length == 2
+                                && args[1] == OffsetDateTime.class) {
+                            return originalResultSet.getObject((Integer) args[0]);
+                        }
+                        try {
+                            return method.invoke(originalResultSet, args);
+                        } catch (java.lang.reflect.InvocationTargetException e) {
+                            throw e.getTargetException();
+                        }
+                    });
+            TableRecords tableRecords = TableRecords.buildRecords(tableMeta, proxyResultSet);
+            Assertions.assertNotNull(tableRecords);
+            Assertions.assertEquals(1, tableRecords.size());
+            Row row = tableRecords.getRows().get(0);
+            Field timeField = row.getFields().stream()
+                    .filter(f -> "time_col".equalsIgnoreCase(f.getName()))
+                    .findFirst()
+                    .orElseThrow(() -> new RuntimeException("time_col not found"));
+            Assertions.assertEquals(Types.TIMESTAMP_WITH_TIMEZONE, timeField.getType());
+            Assertions.assertTrue(timeField.getValue() instanceof OffsetDateTime);
+
+            OffsetDateTime originalTime = (OffsetDateTime) timeField.getValue();
+
+            ObjectMapper mapper = new ObjectMapper()
+                    .registerModule(new JavaTimeModule())
+                    .configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false)
+                    .disableDefaultTyping();
+
+            byte[] encodedBytes = mapper.writeValueAsBytes(originalTime);
+            OffsetDateTime deserializedTime = mapper.readValue(encodedBytes, OffsetDateTime.class);
+            Assertions.assertEquals(originalTime, deserializedTime);
+        } finally {
+            dataSource.close();
+        }
+    }
 }
