@@ -50,6 +50,7 @@ import org.junit.jupiter.api.Test;
 import java.lang.reflect.Field;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
+import java.sql.Connection;
 import java.sql.SQLException;
 import java.sql.Types;
 import java.util.ArrayList;
@@ -138,13 +139,17 @@ public class MariadbUndoLogManagerTest {
 
         dataSourceProxy = DataSourceProxyTest.getDataSourceProxy(dataSource);
 
-        connectionProxy =
-                new ConnectionProxy(dataSourceProxy, dataSource.getConnection().getConnection());
+        connectionProxy = new ConnectionProxy(dataSourceProxy, getPhysicsConnection(dataSource));
         undoLogManager = new MariadbUndoLogManager();
         tableMeta = new TableMeta();
         tableMeta.setTableName("table_plain_executor_test");
     }
 
+    private Connection getPhysicsConnection(DruidDataSource dataSource) throws SQLException {
+        Connection connection = dataSource.getConnection().getConnection();
+        return connection.unwrap(Connection.class);
+    }
+
     @Test
     public void testDeleteUndoLogByLogCreated() throws SQLException {
         Assertions.assertEquals(
