@@ -16,12 +16,6 @@
  */
 package org.apache.seata.saga.statelang.parser;
 
-import java.io.IOException;
-import java.io.InputStream;
-import java.util.Date;
-import java.util.HashMap;
-import java.util.Map;
-
 import org.apache.seata.common.util.BeanUtils;
 import org.apache.seata.saga.statelang.domain.StateMachine;
 import org.apache.seata.saga.statelang.domain.StateMachineInstance;
@@ -32,6 +26,12 @@ import org.apache.seata.saga.statelang.validator.ValidationException;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 
+import java.io.IOException;
+import java.io.InputStream;
+import java.util.Date;
+import java.util.HashMap;
+import java.util.Map;
+
 /**
  * StateParser tests
  */
@@ -41,7 +41,8 @@ public class StateParserTests {
     public void testParser() throws IOException {
         InputStream inputStream = getInputStreamByPath("statelang/simple_statemachine.json");
         String json = IOUtils.toString(inputStream, "UTF-8");
-        StateMachine stateMachine = StateMachineParserFactory.getStateMachineParser(null).parse(json);
+        StateMachine stateMachine =
+                StateMachineParserFactory.getStateMachineParser(null).parse(json);
         stateMachine.setGmtCreate(new Date());
         Assertions.assertNotNull(stateMachine);
 
@@ -49,7 +50,6 @@ public class StateParserTests {
         String outputJson = jsonParser.toJsonString(stateMachine, true);
         System.out.println(outputJson);
 
-
         JsonParser fastjsonParser = JsonParserFactory.getJsonParser("fastjson");
         String fastjsonOutputJson = fastjsonParser.toJsonString(stateMachine, true);
         System.out.println(fastjsonOutputJson);
@@ -69,9 +69,9 @@ public class StateParserTests {
         String outputJson = jsonParser.toJsonString(parsedObj, true);
         System.out.println(outputJson);
 
-
         JsonParser fastjsonParser = JsonParserFactory.getJsonParser("fastjson");
-        Map<String, Object> fastjsonParsedObj = DesignerJsonTransformer.toStandardJson(fastjsonParser.parse(json, Map.class, true));
+        Map<String, Object> fastjsonParsedObj =
+                DesignerJsonTransformer.toStandardJson(fastjsonParser.parse(json, Map.class, true));
         Assertions.assertNotNull(fastjsonParsedObj);
 
         String fastjsonOutputJson = fastjsonParser.toJsonString(fastjsonParsedObj, true);
@@ -91,7 +91,8 @@ public class StateParserTests {
 
     @Test
     public void testMultipleInfiniteLoop() throws IOException {
-        InputStream inputStream = getInputStreamByPath("statelang/simple_statemachine_with_multiple_infinite_loop.json");
+        InputStream inputStream =
+                getInputStreamByPath("statelang/simple_statemachine_with_multiple_infinite_loop.json");
         String json = IOUtils.toString(inputStream, "UTF-8");
         Throwable e = Assertions.assertThrows(ValidationException.class, () -> {
             StateMachineParserFactory.getStateMachineParser(null).parse(json);
@@ -125,9 +126,11 @@ public class StateParserTests {
     public void testGenerateTracingGraphJson() throws Exception {
         InputStream inputStream = getInputStreamByPath("statelang/simple_statemachine_with_layout.json");
         String json = IOUtils.toString(inputStream, "UTF-8");
-        StateMachine stateMachine = StateMachineParserFactory.getStateMachineParser(null).parse(json);
+        StateMachine stateMachine =
+                StateMachineParserFactory.getStateMachineParser(null).parse(json);
         Map<String, String> machineMap = BeanUtils.objectToMap(stateMachine);
-        StateMachineInstance instance = (StateMachineInstance) BeanUtils.mapToObject(machineMap, StateMachineInstanceImpl.class);
+        StateMachineInstance instance =
+                (StateMachineInstance) BeanUtils.mapToObject(machineMap, StateMachineInstanceImpl.class);
         Map<String, Object> context = new HashMap<>();
         context.put("test", "test");
         stateMachine.setContent(json);
