@@ -123,6 +123,5 @@ CREATE TABLE [vgroup_table]
     [vGroup]    nvarchar(255) NOT NULL,
     [namespace] nvarchar(255) NOT NULL,
     [cluster]   nvarchar(255) NOT NULL,
-    PRIMARY KEY CLUSTERED ([vGroup])
-        WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
+    CONSTRAINT uk_vgroup_namespace_cluster UNIQUE ([vGroup], [namespace], [cluster])
 )
\ No newline at end of file
