@@ -25,7 +25,6 @@ import org.springframework.boot.autoconfigure.AutoConfigureOrder;
 import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
 import org.springframework.boot.autoconfigure.condition.ConditionalOnExpression;
 import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
-import org.springframework.boot.autoconfigure.transaction.TransactionAutoConfiguration;
 import org.springframework.boot.context.properties.ConfigurationProperties;
 import org.springframework.context.annotation.Bean;
 import org.springframework.core.Ordered;
@@ -42,7 +41,14 @@ import static org.apache.seata.common.Constants.BEAN_NAME_SPRING_FENCE_CONFIG;
 @ConditionalOnExpression("${seata.enabled:true}")
 @ConditionalOnBean(type = {"javax.sql.DataSource", "org.springframework.transaction.PlatformTransactionManager"})
 @ConditionalOnMissingBean(SpringFenceConfig.class)
-@AutoConfigureAfter({SeataCoreAutoConfiguration.class, TransactionAutoConfiguration.class})
+@AutoConfigureAfter(
+        value = {SeataCoreAutoConfiguration.class},
+        name = {
+            // Spring Boot 2.x, 3.x
+            "org.springframework.boot.autoconfigure.transaction.TransactionAutoConfiguration",
+            // Spring Boot 4.x
+            "org.springframework.boot.transaction.autoconfigure.TransactionAutoConfiguration"
+        })
 @AutoConfigureOrder(Ordered.LOWEST_PRECEDENCE)
 public class SeataSpringFenceAutoConfiguration {
 
