@@ -16,12 +16,12 @@
  */
 package org.apache.seata.serializer.seata.protocol.transaction;
 
-import org.apache.seata.core.protocol.ProtocolConstants;
-import org.apache.seata.serializer.seata.SeataSerializer;
 import org.apache.seata.core.exception.TransactionExceptionCode;
 import org.apache.seata.core.model.BranchStatus;
+import org.apache.seata.core.protocol.ProtocolConstants;
 import org.apache.seata.core.protocol.ResultCode;
 import org.apache.seata.core.protocol.transaction.BranchRollbackResponse;
+import org.apache.seata.serializer.seata.SeataSerializer;
 import org.junit.jupiter.api.Test;
 
 import static org.assertj.core.api.Assertions.assertThat;
@@ -41,7 +41,7 @@ public class BranchRollbackResponseSerializerTest {
      * Test codec.
      */
     @Test
-    public void test_codec(){
+    public void test_codec() {
         BranchRollbackResponse branchRollbackResponse = new BranchRollbackResponse();
         branchRollbackResponse.setBranchId(112232);
         branchRollbackResponse.setXid("123");
@@ -59,7 +59,7 @@ public class BranchRollbackResponseSerializerTest {
         assertThat(branchRollbackResponse2.getResultCode()).isEqualTo(branchRollbackResponse.getResultCode());
         assertThat(branchRollbackResponse2.getXid()).isEqualTo(branchRollbackResponse.getXid());
         assertThat(branchRollbackResponse2.getBranchStatus()).isEqualTo(branchRollbackResponse.getBranchStatus());
-        assertThat(branchRollbackResponse2.getTransactionExceptionCode()).isEqualTo(branchRollbackResponse.getTransactionExceptionCode());
-
+        assertThat(branchRollbackResponse2.getTransactionExceptionCode())
+                .isEqualTo(branchRollbackResponse.getTransactionExceptionCode());
     }
 }
