@@ -24,6 +24,10 @@ import io.netty.handler.codec.http.HttpHeaderNames;
 import io.netty.handler.codec.http.HttpResponse;
 import io.netty.handler.codec.http.HttpResponseStatus;
 import io.netty.handler.codec.http.HttpVersion;
+import io.netty.handler.codec.http2.DefaultHttp2DataFrame;
+import io.netty.handler.codec.http2.DefaultHttp2Headers;
+import io.netty.handler.codec.http2.DefaultHttp2HeadersFrame;
+import io.netty.handler.codec.http2.Http2Headers;
 import org.apache.seata.common.rpc.http.HttpContext;
 import org.apache.seata.common.thread.NamedThreadFactory;
 import org.apache.seata.server.cluster.listener.ClusterChangeEvent;
@@ -51,7 +55,7 @@ public class ClusterWatcherManager implements ClusterChangeListener {
 
     private static final Map<String, Queue<Watcher<HttpContext>>> WATCHERS = new ConcurrentHashMap<>();
 
-    private static final Map<String, Long> GROUP_UPDATE_TIME = new ConcurrentHashMap<>();
+    private static final Map<String, Long> GROUP_UPDATE_TERM = new ConcurrentHashMap<>();
 
     private final ScheduledThreadPoolExecutor scheduledThreadPoolExecutor =
             new ScheduledThreadPoolExecutor(1, new NamedThreadFactory("long-polling", 1));
@@ -85,7 +89,7 @@ public class ClusterWatcherManager implements ClusterChangeListener {
     @Async
     public void onChangeEvent(ClusterChangeEvent event) {
         if (event.getTerm() > 0) {
-            GROUP_UPDATE_TIME.put(event.getGroup(), event.getTerm());
+            GROUP_UPDATE_TERM.put(event.getGroup(), event.getTerm());
             // Notifications are made of changes in cluster information
             Optional.ofNullable(WATCHERS.remove(event.getGroup()))
                     .ifPresent(watchers -> watchers.parallelStream().forEach(this::notifyWatcher));
@@ -98,37 +102,52 @@ public class ClusterWatcherManager implements ClusterChangeListener {
     }
 
     private void sendWatcherResponse(Watcher<HttpContext> watcher, HttpResponseStatus nettyStatus) {
+        String group = watcher.getGroup();
         HttpContext context = watcher.getAsyncContext();
         if (!(context instanceof HttpContext)) {
             logger.warn(
                     "Unsupported context type for watcher on group {}: {}",
-                    watcher.getGroup(),
+                    group,
                     context != null ? context.getClass().getName() : "null");
             return;
         }
         ChannelHandlerContext ctx = context.getContext();
-        if (!context.isHttp2()) {
-            if (ctx.channel().isActive()) {
-                HttpResponse response =
-                        new DefaultFullHttpResponse(HttpVersion.HTTP_1_1, nettyStatus, Unpooled.EMPTY_BUFFER);
-                response.headers().set(HttpHeaderNames.CONTENT_LENGTH, 0);
+        if (!ctx.channel().isActive()) {
+            logger.warn("Netty channel is not active for watcher on group {}, cannot send response.", group);
+            return;
+        }
 
-                if (!context.isKeepAlive()) {
-                    ctx.writeAndFlush(response).addListener(ChannelFutureListener.CLOSE);
-                } else {
-                    ctx.writeAndFlush(response);
-                }
+        if (!context.isHttp2()) {
+            // HTTP/1.1 response
+            HttpResponse response =
+                    new DefaultFullHttpResponse(HttpVersion.HTTP_1_1, nettyStatus, Unpooled.EMPTY_BUFFER);
+            response.headers().set(HttpHeaderNames.CONTENT_LENGTH, 0);
+
+            if (!context.isKeepAlive()) {
+                ctx.writeAndFlush(response).addListener(ChannelFutureListener.CLOSE);
             } else {
-                logger.warn(
-                        "Netty channel is not active for watcher on group {}, cannot send response.",
-                        watcher.getGroup());
+                ctx.writeAndFlush(response);
             }
+        } else {
+            // HTTP/2 response (h2c support)
+            // Send headers frame
+            Http2Headers headers = new DefaultHttp2Headers().status(nettyStatus.codeAsText());
+            headers.set(HttpHeaderNames.CONTENT_LENGTH, "0");
+            ctx.write(new DefaultHttp2HeadersFrame(headers));
+
+            // Send empty data frame with endStream=true to close the stream
+            ctx.writeAndFlush(new DefaultHttp2DataFrame(Unpooled.EMPTY_BUFFER, true))
+                    .addListener(f -> {
+                        if (!f.isSuccess()) {
+                            logger.warn("HTTP2 response send failed, group={}", group, f.cause());
+                        }
+                    });
         }
     }
 
     public void registryWatcher(Watcher<HttpContext> watcher) {
         String group = watcher.getGroup();
-        Long term = GROUP_UPDATE_TIME.get(group);
+        Long term = GROUP_UPDATE_TERM.get(group);
         if (term == null || watcher.getTerm() >= term) {
             WATCHERS.computeIfAbsent(group, value -> new ConcurrentLinkedQueue<>())
                     .add(watcher);
