@@ -32,16 +32,18 @@ public class AddBranchSessionExecute extends AbstractRaftMsgExecute {
 
     @Override
     public Boolean execute(RaftBaseMsg syncMsg) throws Throwable {
-        RaftBranchSessionSyncMsg sessionSyncMsg = (RaftBranchSessionSyncMsg)syncMsg;
-        RaftSessionManager raftSessionManager = (RaftSessionManager) SessionHolder.getRootSessionManager(sessionSyncMsg.getGroup());
+        RaftBranchSessionSyncMsg sessionSyncMsg = (RaftBranchSessionSyncMsg) syncMsg;
+        RaftSessionManager raftSessionManager =
+                (RaftSessionManager) SessionHolder.getRootSessionManager(sessionSyncMsg.getGroup());
         BranchTransactionDTO branchTransactionDTO = sessionSyncMsg.getBranchSession();
         String xid = branchTransactionDTO.getXid();
         GlobalSession globalSession = raftSessionManager.findGlobalSession(xid);
         if (globalSession == null) {
             if (logger.isWarnEnabled()) {
                 logger.warn(
-                    "The transaction corresponding to the XID: {} does not exist, which may cause a two-phase concurrency issue, msg type: {}",
-                    xid, syncMsg.getMsgType());
+                        "The transaction corresponding to the XID: {} does not exist, which may cause a two-phase concurrency issue, msg type: {}",
+                        xid,
+                        syncMsg.getMsgType());
             }
             return false;
         }
@@ -49,10 +51,11 @@ public class AddBranchSessionExecute extends AbstractRaftMsgExecute {
         branchSession.lock();
         globalSession.add(branchSession);
         if (logger.isDebugEnabled()) {
-            logger.debug("addBranch xid: {},branchId: {}", branchTransactionDTO.getXid(),
-                branchTransactionDTO.getBranchId());
+            logger.debug(
+                    "addBranch xid: {},branchId: {}",
+                    branchTransactionDTO.getXid(),
+                    branchTransactionDTO.getBranchId());
         }
         return true;
     }
-
 }
