@@ -16,13 +16,14 @@
  */
 package org.apache.seata.server.cluster.raft.snapshot;
 
-import java.io.Serializable;
 import org.apache.seata.common.util.StringUtils;
 import org.apache.seata.config.ConfigurationFactory;
 import org.apache.seata.core.compressor.CompressorType;
 import org.apache.seata.core.protocol.Version;
 import org.apache.seata.core.serializer.SerializerType;
 
+import java.io.Serializable;
+
 import static org.apache.seata.common.ConfigurationKeys.SERVER_RAFT_COMPRESSOR;
 import static org.apache.seata.common.DefaultValues.DEFAULT_RAFT_COMPRESSOR;
 import static org.apache.seata.common.DefaultValues.DEFAULT_RAFT_SERIALIZATION;
@@ -33,14 +34,14 @@ public class RaftSnapshot implements Serializable {
 
     private byte codec = SerializerType.getByName(DEFAULT_RAFT_SERIALIZATION).getCode();
 
-    private byte compressor = CompressorType
-        .getByName(ConfigurationFactory.getInstance().getConfig(SERVER_RAFT_COMPRESSOR, DEFAULT_RAFT_COMPRESSOR))
-        .getCode();
+    private byte compressor = CompressorType.getByName(
+                    ConfigurationFactory.getInstance().getConfig(SERVER_RAFT_COMPRESSOR, DEFAULT_RAFT_COMPRESSOR))
+            .getCode();
 
     private Object body;
-    
+
     private String version = Version.getCurrent();
-    
+
     private SnapshotType type;
 
     /**
@@ -144,7 +145,5 @@ public class RaftSnapshot implements Serializable {
         SnapshotType(String type) {
             this.type = type;
         }
-
     }
-    
 }
