@@ -16,6 +16,7 @@
  */
 package org.apache.seata.server.instance;
 
+import com.alipay.sofa.jraft.entity.PeerId;
 import org.apache.seata.common.XID;
 import org.apache.seata.common.holder.ObjectHolder;
 import org.apache.seata.common.metadata.ClusterRole;
@@ -65,15 +66,16 @@ public class RaftServerInstanceStrategy extends AbstractSeataInstanceStrategy
         String clusterType = String.valueOf(StoreConfig.getSessionMode());
         instance.addMetadata("cluster-type", "raft".equalsIgnoreCase(clusterType) ? clusterType : "default");
         RaftStateMachine stateMachine = RaftServerManager.getRaftServer(unit).getRaftStateMachine();
-        long term = RaftServerManager.getRaftServer(unit)
-                .getRaftStateMachine()
-                .getCurrentTerm()
-                .get();
+        long term = stateMachine.getCurrentTerm().get();
         instance.setTerm(term);
         instance.setRole(stateMachine.isLeader() ? ClusterRole.LEADER : ClusterRole.FOLLOWER);
         // load node Endpoint
         instance.setControl(new Node.Endpoint(XID.getIpAddress(), serverProperties.getPort(), "http"));
 
+        PeerId peerId =
+                RaftServerManager.getRaftServer(raftProperties.getGroup()).getServerId();
+        instance.setInternal(new Node.Endpoint(peerId.getIp(), peerId.getPort(), "raft"));
+
         // load metadata
         for (PropertySource<?> propertySource : environment.getPropertySources()) {
             if (propertySource instanceof EnumerablePropertySource) {
