@@ -43,11 +43,6 @@ public class RateLimitInfo {
      */
     private String applicationId;
 
-    /**
-     * The Client id.
-     */
-    private String clientId;
-
     /**
      * The Server ip address and port.
      */
@@ -56,12 +51,11 @@ public class RateLimitInfo {
     private RateLimitInfo() {}
 
     public static RateLimitInfo generateRateLimitInfo(
-            String applicationId, String type, String clientId, String serverIpAddressAndPort) {
+            String applicationId, String type, String serverIpAddressAndPort) {
         RateLimitInfo rateLimitInfo = new RateLimitInfo();
         rateLimitInfo.setTraceId(String.valueOf(UUIDGenerator.generateUUID()));
         rateLimitInfo.setLimitType(type);
         rateLimitInfo.setApplicationId(applicationId);
-        rateLimitInfo.setClientId(clientId);
         rateLimitInfo.setServerIpAddressAndPort(serverIpAddressAndPort);
         return rateLimitInfo;
     }
@@ -90,14 +84,6 @@ public class RateLimitInfo {
         this.applicationId = applicationId;
     }
 
-    public String getClientId() {
-        return clientId;
-    }
-
-    public void setClientId(String clientId) {
-        this.clientId = clientId;
-    }
-
     public String getServerIpAddressAndPort() {
         return serverIpAddressAndPort;
     }
@@ -111,8 +97,7 @@ public class RateLimitInfo {
         return "RateLimitInfo{" + "traceId='"
                 + traceId + '\'' + ", limitType='"
                 + limitType + '\'' + ", applicationId='"
-                + applicationId + '\'' + ", clientId='"
-                + clientId + '\'' + ", serverIpAddressAndPort='"
+                + applicationId + '\'' + ", serverIpAddressAndPort='"
                 + serverIpAddressAndPort + '\'' + '}';
     }
 }
