@@ -48,7 +48,6 @@ import java.util.Objects;
 import java.util.concurrent.CompletableFuture;
 
 import static java.io.File.separator;
-import static org.apache.seata.common.ConfigurationKeys.SERVER_SERVICE_PORT_CAMEL;
 import static org.apache.seata.common.DefaultValues.DEFAULT_DISTRIBUTED_LOCK_EXPIRE_TIME;
 import static org.apache.seata.common.DefaultValues.DEFAULT_SEATA_GROUP;
 import static org.apache.seata.common.DefaultValues.DEFAULT_SESSION_STORE_FILE_DIR;
@@ -125,11 +124,11 @@ public class SessionHolder {
                 String vGroupMappingStorePath =
                         CONFIG.getConfig(ConfigurationKeys.STORE_FILE_DIR, DEFAULT_VGROUP_MAPPING_STORE_FILE_DIR)
                                 + separator
-                                + System.getProperty(SERVER_SERVICE_PORT_CAMEL);
+                                + XID.getPort();
                 String sessionStorePath =
                         CONFIG.getConfig(ConfigurationKeys.STORE_FILE_DIR, DEFAULT_SESSION_STORE_FILE_DIR)
                                 + separator
-                                + System.getProperty(SERVER_SERVICE_PORT_CAMEL);
+                                + XID.getPort();
                 if (StringUtils.isBlank(sessionStorePath) || StringUtils.isBlank(vGroupMappingStorePath)) {
                     throw new StoreException("the {store.file.dir} is empty.");
                 }
