@@ -16,8 +16,8 @@
  */
 import org.apache.seata.common.XID;
 import org.apache.seata.common.util.NetUtil;
-import org.apache.seata.core.rpc.netty.NettyRemotingServer;
 import org.apache.seata.common.util.UUIDGenerator;
+import org.apache.seata.core.rpc.netty.NettyRemotingServer;
 import org.apache.seata.server.coordinator.DefaultCoordinator;
 
 import java.util.concurrent.LinkedBlockingQueue;
@@ -30,9 +30,8 @@ import java.util.concurrent.TimeUnit;
  */
 public class ServerTest {
 
-    private static final ThreadPoolExecutor workingThreads = new ThreadPoolExecutor(100, 500, 500, TimeUnit.SECONDS,
-            new LinkedBlockingQueue(20000), new ThreadPoolExecutor.CallerRunsPolicy());
-
+    private static final ThreadPoolExecutor workingThreads = new ThreadPoolExecutor(
+            100, 500, 500, TimeUnit.SECONDS, new LinkedBlockingQueue(20000), new ThreadPoolExecutor.CallerRunsPolicy());
 
     /**
      * The entry point of application.
@@ -49,5 +48,4 @@ public class ServerTest {
         nettyServer.init();
         System.exit(0);
     }
-
 }
