@@ -18,22 +18,18 @@ package org.apache.seata.server.lock;
 
 import org.apache.seata.core.store.DefaultDistributedLocker;
 import org.apache.seata.core.store.DistributedLocker;
-import org.apache.seata.server.DynamicPortTestConfig;
+import org.apache.seata.server.BaseSpringBootTest;
 import org.apache.seata.server.lock.distributed.DistributedLockerFactory;
 import org.apache.seata.server.storage.redis.lock.RedisDistributedLocker;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
-import org.springframework.boot.test.context.SpringBootTest;
-import org.springframework.context.annotation.Import;
 
 /**
  * @description Distributed locker factory test
  */
-@SpringBootTest
-@Import(DynamicPortTestConfig.class)
-public class DistributedLockerFactoryTest {
+public class DistributedLockerFactoryTest extends BaseSpringBootTest {
 
     @BeforeEach
     public void setUp() {
