@@ -21,21 +21,17 @@ import ch.qos.logback.classic.spi.ILoggingEvent;
 import ch.qos.logback.core.Appender;
 import com.github.danielwegener.logback.kafka.KafkaAppender;
 import net.logstash.logback.appender.LogstashTcpSocketAppender;
-import org.apache.seata.server.DynamicPortTestConfig;
+import org.apache.seata.server.BaseSpringBootTest;
 import org.apache.seata.server.logging.logback.appender.MetricLogbackAppender;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 import org.slf4j.impl.StaticLoggerBinder;
-import org.springframework.boot.test.context.SpringBootTest;
-import org.springframework.context.annotation.Import;
 
 import java.lang.reflect.Field;
 import java.util.Iterator;
 
-@SpringBootTest
-@Import(DynamicPortTestConfig.class)
-public class AppenderTest {
+public class AppenderTest extends BaseSpringBootTest {
 
     @BeforeAll
     public static void init() {
