@@ -17,14 +17,11 @@
 package org.apache.seata.server.session.redis;
 
 import org.apache.seata.common.loader.EnhancedServiceLoader;
-import org.apache.seata.server.DynamicPortTestConfig;
 import org.apache.seata.server.storage.redis.session.RedisSessionManager;
 import org.apache.seata.server.storage.redis.store.RedisLuaTransactionStoreManager;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.condition.EnabledIfSystemProperty;
-import org.springframework.boot.test.context.SpringBootTest;
 import org.springframework.context.ApplicationContext;
-import org.springframework.context.annotation.Import;
 
 import java.io.IOException;
 
@@ -32,9 +29,7 @@ import java.io.IOException;
  * test RedisLuaTransactionStoreManager
  *
  */
-@SpringBootTest
 @EnabledIfSystemProperty(named = "redisCaseEnabled", matches = "true")
-@Import(DynamicPortTestConfig.class)
 public class RedisLuaTransactionStoreManagerTest extends RedisTransactionStoreManagerTest {
 
     /**
