@@ -16,7 +16,6 @@
  */
 package org.apache.seata.sqlparser.druid.oscar;
 
-import com.alibaba.druid.sql.SQLUtils;
 import com.alibaba.druid.sql.ast.SQLStatement;
 import com.alibaba.druid.sql.ast.statement.SQLDeleteStatement;
 import com.alibaba.druid.sql.dialect.oracle.ast.expr.OracleArgumentExpr;
@@ -27,65 +26,55 @@ import org.junit.jupiter.api.Test;
 
 import java.util.ArrayList;
 import java.util.HashMap;
-import java.util.List;
 import java.util.Map;
 
 /**
  * The type Oscar delete recognizer test.
  */
-public class OscarDeleteRecognizerTest {
-
-    private static final String DB_TYPE = "oscar";
+public class OscarDeleteRecognizerTest extends AbstractOscarRecognizerTest {
 
     @Test
     public void testGetSqlType() {
         String sql = "delete from t where id = ?";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, DB_TYPE);
+        SQLStatement sqlStatement = getSQLStatement(sql);
 
-        OscarDeleteRecognizer recognizer = new OscarDeleteRecognizer(sql, asts.get(0));
+        OscarDeleteRecognizer recognizer = new OscarDeleteRecognizer(sql, sqlStatement);
         Assertions.assertEquals(recognizer.getSQLType(), SQLType.DELETE);
     }
 
     @Test
     public void testGetTableAlias() {
         String sql = "delete from t where id = ?";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, DB_TYPE);
+        SQLStatement sqlStatement = getSQLStatement(sql);
 
-        OscarDeleteRecognizer recognizer = new OscarDeleteRecognizer(sql, asts.get(0));
+        OscarDeleteRecognizer recognizer = new OscarDeleteRecognizer(sql, sqlStatement);
         Assertions.assertNull(recognizer.getTableAlias());
     }
 
     @Test
     public void testGetTableName() {
         String sql = "delete from t where id = ?";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, DB_TYPE);
+        SQLStatement sqlStatement = getSQLStatement(sql);
 
-        OscarDeleteRecognizer recognizer = new OscarDeleteRecognizer(sql, asts.get(0));
+        OscarDeleteRecognizer recognizer = new OscarDeleteRecognizer(sql, sqlStatement);
         Assertions.assertEquals(recognizer.getTableName(), "t");
     }
 
     @Test
     public void testGetWhereCondition_0() {
         String sql = "delete from t";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, DB_TYPE);
+        SQLStatement sqlStatement = getSQLStatement(sql);
 
-        OscarDeleteRecognizer recognizer = new OscarDeleteRecognizer(sql, asts.get(0));
-        String whereCondition = recognizer.getWhereCondition(
-                new ParametersHolder() {
-                    @Override
-                    public Map<Integer, ArrayList<Object>> getParameters() {
-                        return null;
-                    }
-                },
-                new ArrayList<>());
+        OscarDeleteRecognizer recognizer = new OscarDeleteRecognizer(sql, sqlStatement);
+        String whereCondition = recognizer.getWhereCondition(() -> null, new ArrayList<>());
 
         // test for no condition
         Assertions.assertEquals("", whereCondition);
 
         sql = "delete from t where id = ?";
-        asts = SQLUtils.parseStatements(sql, DB_TYPE);
+        sqlStatement = getSQLStatement(sql);
 
-        recognizer = new OscarDeleteRecognizer(sql, asts.get(0));
+        recognizer = new OscarDeleteRecognizer(sql, sqlStatement);
         whereCondition = recognizer.getWhereCondition(
                 new ParametersHolder() {
                     @Override
@@ -103,8 +92,8 @@ public class OscarDeleteRecognizerTest {
         Assertions.assertEquals("id = ?", whereCondition);
 
         sql = "delete from t where id in (?)";
-        asts = SQLUtils.parseStatements(sql, DB_TYPE);
-        recognizer = new OscarDeleteRecognizer(sql, asts.get(0));
+        sqlStatement = getSQLStatement(sql);
+        recognizer = new OscarDeleteRecognizer(sql, sqlStatement);
         whereCondition = recognizer.getWhereCondition(
                 new ParametersHolder() {
                     @Override
@@ -122,8 +111,8 @@ public class OscarDeleteRecognizerTest {
         Assertions.assertEquals("id IN (?)", whereCondition);
 
         sql = "delete from t where id between ? and ?";
-        asts = SQLUtils.parseStatements(sql, DB_TYPE);
-        recognizer = new OscarDeleteRecognizer(sql, asts.get(0));
+        sqlStatement = getSQLStatement(sql);
+        recognizer = new OscarDeleteRecognizer(sql, sqlStatement);
         whereCondition = recognizer.getWhereCondition(
                 new ParametersHolder() {
                     @Override
@@ -145,18 +134,9 @@ public class OscarDeleteRecognizerTest {
         // test for exception
         Assertions.assertThrows(IllegalArgumentException.class, () -> {
             String s = "delete from t where id in (?)";
-            List<SQLStatement> sqlStatements = SQLUtils.parseStatements(s, DB_TYPE);
-            SQLDeleteStatement deleteAst = (SQLDeleteStatement) sqlStatements.get(0);
+            SQLDeleteStatement deleteAst = (SQLDeleteStatement) getSQLStatement(s);
             deleteAst.setWhere(new OracleArgumentExpr());
-            new OscarDeleteRecognizer(s, deleteAst)
-                    .getWhereCondition(
-                            new ParametersHolder() {
-                                @Override
-                                public Map<Integer, ArrayList<Object>> getParameters() {
-                                    return new HashMap<>();
-                                }
-                            },
-                            new ArrayList<>());
+            new OscarDeleteRecognizer(s, deleteAst).getWhereCondition(() -> new HashMap<>(), new ArrayList<>());
         });
     }
 
@@ -164,34 +144,34 @@ public class OscarDeleteRecognizerTest {
     public void testGetWhereCondition_1() {
 
         String sql = "delete from t";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, DB_TYPE);
+        SQLStatement sqlStatement = getSQLStatement(sql);
 
-        OscarDeleteRecognizer recognizer = new OscarDeleteRecognizer(sql, asts.get(0));
+        OscarDeleteRecognizer recognizer = new OscarDeleteRecognizer(sql, sqlStatement);
         String whereCondition = recognizer.getWhereCondition();
 
         // test for no condition
         Assertions.assertEquals("", whereCondition);
 
         sql = "delete from t where id = 1";
-        asts = SQLUtils.parseStatements(sql, DB_TYPE);
+        sqlStatement = getSQLStatement(sql);
 
-        recognizer = new OscarDeleteRecognizer(sql, asts.get(0));
+        recognizer = new OscarDeleteRecognizer(sql, sqlStatement);
         whereCondition = recognizer.getWhereCondition();
 
         // test for normal sql
         Assertions.assertEquals("id = 1", whereCondition);
 
         sql = "delete from t where id in (1)";
-        asts = SQLUtils.parseStatements(sql, DB_TYPE);
-        recognizer = new OscarDeleteRecognizer(sql, asts.get(0));
+        sqlStatement = getSQLStatement(sql);
+        recognizer = new OscarDeleteRecognizer(sql, sqlStatement);
         whereCondition = recognizer.getWhereCondition();
 
         // test for sql with in
         Assertions.assertEquals("id IN (1)", whereCondition);
 
         sql = "delete from t where id between 1 and 2";
-        asts = SQLUtils.parseStatements(sql, DB_TYPE);
-        recognizer = new OscarDeleteRecognizer(sql, asts.get(0));
+        sqlStatement = getSQLStatement(sql);
+        recognizer = new OscarDeleteRecognizer(sql, sqlStatement);
         whereCondition = recognizer.getWhereCondition();
         // test for sql with in
         Assertions.assertEquals("id BETWEEN 1 AND 2", whereCondition);
@@ -199,8 +179,7 @@ public class OscarDeleteRecognizerTest {
         // test for exception
         Assertions.assertThrows(IllegalArgumentException.class, () -> {
             String s = "delete from t where id in (1)";
-            List<SQLStatement> sqlStatements = SQLUtils.parseStatements(s, DB_TYPE);
-            SQLDeleteStatement deleteAst = (SQLDeleteStatement) sqlStatements.get(0);
+            SQLDeleteStatement deleteAst = (SQLDeleteStatement) getSQLStatement(s);
             deleteAst.setWhere(new OracleArgumentExpr());
             new OscarDeleteRecognizer(s, deleteAst).getWhereCondition();
         });
