@@ -16,10 +16,10 @@
  */
 package org.apache.seata.sqlparser.druid.oscar;
 
-import com.alibaba.druid.sql.SQLUtils;
 import com.alibaba.druid.sql.ast.SQLStatement;
 import com.alibaba.druid.sql.ast.statement.SQLInsertStatement;
 import com.alibaba.druid.sql.dialect.oracle.ast.expr.OracleBinaryDoubleExpr;
+import com.alibaba.druid.sql.dialect.oracle.ast.expr.OracleIntervalExpr;
 import org.apache.seata.sqlparser.SQLParsingException;
 import org.apache.seata.sqlparser.SQLType;
 import org.apache.seata.sqlparser.struct.NotPlaceholderExpr;
@@ -32,34 +32,32 @@ import java.util.List;
 /**
  * The type Oscar insert recognizer test.
  */
-public class OscarInsertRecognizerTest {
-
-    private static final String DB_TYPE = "oscar";
+public class OscarInsertRecognizerTest extends AbstractOscarRecognizerTest {
 
     @Test
     public void testGetSqlType() {
         String sql = "insert into t(id) values (?)";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, DB_TYPE);
+        SQLStatement sqlStatement = getSQLStatement(sql);
 
-        OscarInsertRecognizer recognizer = new OscarInsertRecognizer(sql, asts.get(0));
+        OscarInsertRecognizer recognizer = new OscarInsertRecognizer(sql, sqlStatement);
         Assertions.assertEquals(recognizer.getSQLType(), SQLType.INSERT);
     }
 
     @Test
     public void testGetTableAlias() {
         String sql = "insert into t(id) values (?)";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, DB_TYPE);
+        SQLStatement sqlStatement = getSQLStatement(sql);
 
-        OscarInsertRecognizer recognizer = new OscarInsertRecognizer(sql, asts.get(0));
+        OscarInsertRecognizer recognizer = new OscarInsertRecognizer(sql, sqlStatement);
         Assertions.assertNull(recognizer.getTableAlias());
     }
 
     @Test
     public void testGetTableName() {
         String sql = "insert into t(id) values (?)";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, DB_TYPE);
+        SQLStatement sqlStatement = getSQLStatement(sql);
 
-        OscarInsertRecognizer recognizer = new OscarInsertRecognizer(sql, asts.get(0));
+        OscarInsertRecognizer recognizer = new OscarInsertRecognizer(sql, sqlStatement);
         Assertions.assertEquals(recognizer.getTableName(), "t");
     }
 
@@ -68,25 +66,24 @@ public class OscarInsertRecognizerTest {
 
         // test for no column
         String sql = "insert into t values (?)";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, DB_TYPE);
+        SQLStatement sqlStatement = getSQLStatement(sql);
 
-        OscarInsertRecognizer recognizer = new OscarInsertRecognizer(sql, asts.get(0));
+        OscarInsertRecognizer recognizer = new OscarInsertRecognizer(sql, sqlStatement);
         List<String> insertColumns = recognizer.getInsertColumns();
         Assertions.assertNull(insertColumns);
 
         // test for normal
         sql = "insert into t(a) values (?)";
-        asts = SQLUtils.parseStatements(sql, DB_TYPE);
+        sqlStatement = getSQLStatement(sql);
 
-        recognizer = new OscarInsertRecognizer(sql, asts.get(0));
+        recognizer = new OscarInsertRecognizer(sql, sqlStatement);
         insertColumns = recognizer.getInsertColumns();
         Assertions.assertEquals(1, insertColumns.size());
 
         // test for exception
         Assertions.assertThrows(SQLParsingException.class, () -> {
             String s = "insert into t(a) values (?)";
-            List<SQLStatement> sqlStatements = SQLUtils.parseStatements(s, DB_TYPE);
-            SQLInsertStatement sqlInsertStatement = (SQLInsertStatement) sqlStatements.get(0);
+            SQLInsertStatement sqlInsertStatement = (SQLInsertStatement) getSQLStatement(s);
             sqlInsertStatement.getColumns().add(new OracleBinaryDoubleExpr());
 
             OscarInsertRecognizer oscarInsertRecognizer = new OscarInsertRecognizer(s, sqlInsertStatement);
@@ -99,18 +96,17 @@ public class OscarInsertRecognizerTest {
         final int pkIndex = 0;
         // test for null value
         String sql = "insert into t(id, no, name, age, time) values (id_seq.nextval, null, 'a', ?, now())";
-        List<SQLStatement> asts = SQLUtils.parseStatements(sql, DB_TYPE);
+        SQLStatement sqlStatement = getSQLStatement(sql);
 
-        OscarInsertRecognizer recognizer = new OscarInsertRecognizer(sql, asts.get(0));
+        OscarInsertRecognizer recognizer = new OscarInsertRecognizer(sql, sqlStatement);
         List<List<Object>> insertRows = recognizer.getInsertRows(Collections.singletonList(pkIndex));
         Assertions.assertEquals(1, insertRows.size());
 
         // test for exception
         Assertions.assertThrows(SQLParsingException.class, () -> {
             String s = "insert into t(a) values (?)";
-            List<SQLStatement> sqlStatements = SQLUtils.parseStatements(s, DB_TYPE);
-            SQLInsertStatement sqlInsertStatement = (SQLInsertStatement) sqlStatements.get(0);
-            sqlInsertStatement.getValuesList().get(0).getValues().set(pkIndex, new OracleBinaryDoubleExpr());
+            SQLInsertStatement sqlInsertStatement = (SQLInsertStatement) getSQLStatement(s);
+            sqlInsertStatement.getValuesList().get(0).getValues().set(pkIndex, new OracleIntervalExpr());
 
             OscarInsertRecognizer oscarInsertRecognizer = new OscarInsertRecognizer(s, sqlInsertStatement);
             oscarInsertRecognizer.getInsertRows(Collections.singletonList(pkIndex));
@@ -120,9 +116,9 @@ public class OscarInsertRecognizerTest {
     @Test
     public void testNotPlaceholder_giveValidPkIndex() {
         String sql = "insert into test(create_time) values(sysdate)";
-        List<SQLStatement> sqlStatements = SQLUtils.parseStatements(sql, DB_TYPE);
+        SQLStatement sqlStatement = getSQLStatement(sql);
 
-        OscarInsertRecognizer oscar = new OscarInsertRecognizer(sql, sqlStatements.get(0));
+        OscarInsertRecognizer oscar = new OscarInsertRecognizer(sql, sqlStatement);
         List<List<Object>> insertRows = oscar.getInsertRows(Collections.singletonList(-1));
         Assertions.assertTrue(insertRows.get(0).get(0) instanceof NotPlaceholderExpr);
     }
